"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var CanvasGradient_1 = require("./CanvasGradient");
var ColorHelper_1 = require("./ColorHelper");
var TNSPath2D_1 = require("./TNSPath2D");
var image_source_1 = require("@nativescript/core/image-source");
var ImageData_1 = require("./ImageData");
var TextMetrics_1 = require("./TextMetrics");
var color_1 = require("@nativescript/core/color");
var TNSImageAsset_1 = require("./TNSImageAsset");
var CanvasPattern_1 = require("./CanvasPattern");
var TNSCanvas_1 = require("./TNSCanvas");
var TNSCanvasRenderingContext2D = (function (_super) {
    __extends(TNSCanvasRenderingContext2D, _super);
    function TNSCanvasRenderingContext2D(context) {
        var _this = _super.call(this) || this;
        _this._shadowColor = 'transparent';
        _this._fillStyle = 'black';
        _this._strokeStyle = 'black';
        _this.context = context;
        return _this;
    }
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "native", {
        get: function () {
            return this.context;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "canvas", {
        get: function () {
            return this._canvas;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowColor", {
        get: function () {
            this.log('shadowColor');
            return this._shadowColor;
        },
        set: function (color) {
            this.log('shadowColor value:', color);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                if (typeof color === 'string' && !isNaN(parseInt(color))) {
                    this.context.setShadowColor(new color_1.Color(parseInt(color)).argb);
                }
                else {
                    this.context.setShadowColor(new color_1.Color(color).argb);
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "font", {
        get: function () {
            this.log('get font');
            return this.context.getFont();
        },
        set: function (value) {
            this.log('set font value:', value);
            if (this.context) {
                this.context.setFont(value);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "direction", {
        get: function () {
            this.log('direction');
            return this.context.getDirection();
        },
        set: function (value) {
            this.log('direction value:', value);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setDirection(value);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "globalAlpha", {
        get: function () {
            this.log('globalAlpha');
            return this.context.getGlobalAlpha();
        },
        set: function (alpha) {
            this.log('globalAlpha value:', alpha);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setGlobalAlpha(alpha);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "imageSmoothingEnabled", {
        get: function () {
            this.log('imageSmoothingEnabled');
            return this.context.getImageSmoothingEnabled();
        },
        set: function (enabled) {
            this.log('imageSmoothingEnabled value:', enabled);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setImageSmoothingEnabled(enabled);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "imageSmoothingQuality", {
        get: function () {
            this.log('imageSmoothingQuality');
            return this.context.getImageSmoothingQuality().toString();
        },
        set: function (quality) {
            this.log('imageSmoothingQuality value:', quality);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (quality) {
                    case 'high':
                        this.context.setImageSmoothingQuality(com.github.triniwiz.canvas.CanvasRenderingContext2D.ImageSmoothingQuality.High);
                        break;
                    case 'medium':
                        this.context.setImageSmoothingQuality(com.github.triniwiz.canvas.CanvasRenderingContext2D.ImageSmoothingQuality.Medium);
                        break;
                    default:
                        this.context.setImageSmoothingQuality(com.github.triniwiz.canvas.CanvasRenderingContext2D.ImageSmoothingQuality.Low);
                        break;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineDashOffset", {
        get: function () {
            this.log('lineDashOffset');
            return this.context.getLineDashOffset();
        },
        set: function (offset) {
            this.log('lineDashOffset value:', offset);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setLineDashOffset(offset);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineJoin", {
        get: function () {
            this.log('lineJoin');
            return this.context.getLineJoin().toString();
        },
        set: function (join) {
            this.log('lineJoin value:', join);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (join) {
                    case 'bevel':
                        this.context.setLineJoin(com.github.triniwiz.canvas.CanvasRenderingContext2D.LineJoin.Bevel);
                        break;
                    case 'round':
                        this.context.setLineJoin(com.github.triniwiz.canvas.CanvasRenderingContext2D.LineJoin.Round);
                        break;
                    default:
                        this.context.setLineJoin(com.github.triniwiz.canvas.CanvasRenderingContext2D.LineJoin.Miter);
                        break;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineCap", {
        get: function () {
            this.log('lineCap');
            return this.context.getLineCap().toString();
        },
        set: function (cap) {
            this.log('lineCap value:', cap);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (cap) {
                    case 'round':
                        this.context.setLineCap(com.github.triniwiz.canvas.CanvasRenderingContext2D.LineCap.Round);
                        break;
                    case 'square':
                        this.context.setLineCap(com.github.triniwiz.canvas.CanvasRenderingContext2D.LineCap.Square);
                        break;
                    default:
                        this.context.setLineCap(com.github.triniwiz.canvas.CanvasRenderingContext2D.LineCap.Butt);
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "miterLimit", {
        get: function () {
            this.log('miterLimit value:');
            return this.context.getMiterLimit();
        },
        set: function (limit) {
            this.log('miterLimit value:', limit);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setMiterLimit(limit);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowBlur", {
        get: function () {
            this.log('shadowBlur');
            return this.context.getShadowBlur();
        },
        set: function (blur) {
            this.log('shadowBlur value:', blur);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setShadowBlur(blur);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowOffsetX", {
        get: function () {
            this.log('shadowOffsetX');
            return this.context.getShadowOffsetX();
        },
        set: function (x) {
            this.log('shadowOffsetX value:', x);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setShadowOffsetX(x);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowOffsetY", {
        get: function () {
            this.log('shadowOffsetY');
            return this.context.getShadowOffsetY();
        },
        set: function (y) {
            this.log('shadowOffsetY value:', y);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setShadowOffsetY(y);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "textAlign", {
        get: function () {
            this.log('textAlign');
            return this.context.getTextAlign().toString();
        },
        set: function (alignment) {
            this.log('textAlign value:', alignment);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (alignment) {
                    case 'start':
                        this.context.setTextAlign(com.github.triniwiz.canvas.CanvasTextAlignment.Start);
                        break;
                    case 'center':
                        this.context.setTextAlign(com.github.triniwiz.canvas.CanvasTextAlignment.Center);
                        break;
                    case 'end':
                        this.context.setTextAlign(com.github.triniwiz.canvas.CanvasTextAlignment.End);
                        break;
                    case 'right':
                        this.context.setTextAlign(com.github.triniwiz.canvas.CanvasTextAlignment.Right);
                        break;
                    default:
                        this.context.setTextAlign(com.github.triniwiz.canvas.CanvasTextAlignment.Left);
                        break;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "globalCompositeOperation", {
        get: function () {
            this.log('globalCompositeOperation');
            return this.context.getGlobalCompositeOperation().toString();
        },
        set: function (composite) {
            this.log('globalCompositeOperation value:', composite);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                var operation = void 0;
                switch (composite.toLowerCase()) {
                    case 'source-over':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.SourceOver;
                        break;
                    case 'source-in':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.SourceIn;
                        break;
                    case 'source-out':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.SourceoOut;
                        break;
                    case 'source-atop':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.SourceAtop;
                        break;
                    case 'destination-over':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.DestinationOver;
                        break;
                    case 'destination-in':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.DestinationIn;
                        break;
                    case 'destination-out':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.DestinationOut;
                        break;
                    case 'destination-atop':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.DestinationAtop;
                        break;
                    case 'lighter':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Lighter;
                        break;
                    case 'copy':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Copy;
                        break;
                    case 'xor':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Xor;
                        break;
                    case 'multiply':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Multiply;
                        break;
                    case 'screen':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Screen;
                        break;
                    case 'overlay':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Overlay;
                        break;
                    case 'darken':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Darken;
                        break;
                    case 'lighten':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Lighten;
                        break;
                    case 'color-dodge':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.ColorDodge;
                        break;
                    case 'color-burn':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.ColorBurn;
                        break;
                    case 'hard-light':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.HardLight;
                        break;
                    case 'soft-light':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.SoftLight;
                        break;
                    case 'difference':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Difference;
                        break;
                    case 'exclusion':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Exclusion;
                        break;
                    case 'hue':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Hue;
                        break;
                    case 'saturation':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Saturation;
                        break;
                    case 'color':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Color;
                        break;
                    case 'luminosity':
                        operation = com.github.triniwiz.canvas.CanvasCompositeOperationType.Luminosity;
                        break;
                }
                this.context.setGlobalCompositeOperation(operation);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "fillStyle", {
        get: function () {
            this.log('fillStyle');
            return this._fillStyle;
        },
        set: function (color) {
            this.log('fillStyle:', color);
            this._ensureLayoutBeforeDraw();
            var nativeStyle;
            if (this._fillStyle === color) {
                return;
            }
            if (!(color instanceof CanvasGradient_1.CanvasGradient || color instanceof CanvasPattern_1.CanvasPattern) && TNSCanvasRenderingContext2D.colorCache[color]) {
                var cache = TNSCanvasRenderingContext2D.colorCache[color];
                this._fillStyle = cache;
                this.context.setFillStyle(cache);
                return;
            }
            if (color instanceof CanvasGradient_1.CanvasGradient) {
                nativeStyle = color.native;
                this._fillStyle = color;
            }
            else if (color instanceof CanvasPattern_1.CanvasPattern) {
                nativeStyle = color.native;
                this._fillStyle = color;
            }
            else {
                if (typeof color === 'string' && color.startsWith('hsla')) {
                    color = ColorHelper_1.ColorHandler.HSLAToRGBA(color, false);
                }
                else if (typeof color === 'string' && color.startsWith('hsl')) {
                    color = ColorHelper_1.ColorHandler.HSLToRGB(color, false);
                }
                if (typeof color === 'string' && color.indexOf('Invalid input color') > -1) {
                    color = 'black';
                }
                if (color === undefined || color === null) {
                    color = 'black';
                }
                this._fillStyle = color;
                nativeStyle = new color_1.Color(color).argb;
                TNSCanvasRenderingContext2D.colorCache[color] = nativeStyle;
            }
            this.context.setFillStyle(nativeStyle);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "strokeStyle", {
        get: function () {
            this.log('strokeStyle');
            return this._strokeStyle;
        },
        set: function (color) {
            this.log('strokeStyle value:', color);
            this._ensureLayoutBeforeDraw();
            var nativeStyle;
            if (this._strokeStyle === color) {
                return;
            }
            if (!(color instanceof CanvasGradient_1.CanvasGradient || color instanceof CanvasPattern_1.CanvasPattern) && TNSCanvasRenderingContext2D.colorCache[color]) {
                var cache = TNSCanvasRenderingContext2D.colorCache[color];
                this._strokeStyle = cache;
                this.context.setStrokeStyle(cache);
                return;
            }
            if (color instanceof CanvasGradient_1.CanvasGradient) {
                nativeStyle = color.native;
                this._strokeStyle = color;
            }
            else if (color instanceof CanvasPattern_1.CanvasPattern) {
                nativeStyle = color.native;
                this._strokeStyle = color;
            }
            else {
                if (typeof color === 'string' && color.startsWith('hsla')) {
                    color = ColorHelper_1.ColorHandler.HSLAToRGBA(color, false);
                }
                else if (typeof color === 'string' && color.startsWith('hsl')) {
                    color = ColorHelper_1.ColorHandler.HSLToRGB(color, false);
                }
                if (typeof color === 'string' && color.indexOf('Invalid input color') > -1) {
                    color = 'black';
                }
                this._strokeStyle = color;
                nativeStyle = new color_1.Color(color).argb;
                TNSCanvasRenderingContext2D.colorCache[color] = nativeStyle;
            }
            this.context.setStrokeStyle(nativeStyle);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineWidth", {
        get: function () {
            this.log('lineWidth');
            return this.context.getLineWidth();
        },
        set: function (width) {
            this.log('lineWidth value:', width);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.setLineWidth(width);
            }
        },
        enumerable: true,
        configurable: true
    });
    TNSCanvasRenderingContext2D.prototype.addHitRegion = function (region) {
    };
    TNSCanvasRenderingContext2D.prototype.arc = function (x, y, radius, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.log('arc value:', x, y, radius, startAngle, endAngle, anticlockwise);
        this._ensureLayoutBeforeDraw();
        this.context.arc(x, y, radius, startAngle, endAngle, anticlockwise);
    };
    TNSCanvasRenderingContext2D.prototype.arcTo = function (x1, y1, x2, y2, radius) {
        this.log('arcTo value:', x1, y1, x2, y2, radius);
        this._ensureLayoutBeforeDraw();
        this.context.arcTo(x1, y1, x2, y2, radius);
    };
    TNSCanvasRenderingContext2D.prototype.beginPath = function () {
        this.log('beginPath');
        this._ensureLayoutBeforeDraw();
        this.context.beginPath();
    };
    TNSCanvasRenderingContext2D.prototype.bezierCurveTo = function (cp1x, cp1y, cp2x, cp2y, x, y) {
        this.log('bezierCurveTo value:', cp1x, cp1y, cp2x, cp2y, x, y);
        this._ensureLayoutBeforeDraw();
        this.context.bezierCurveTo(cp1x, cp1y, cp2x, cp2y, x, y);
    };
    TNSCanvasRenderingContext2D.prototype.clearHitRegions = function () {
    };
    TNSCanvasRenderingContext2D.prototype.clearRect = function (x, y, width, height) {
        this.log('clearRect value:', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.clearRect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.clip = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['clip value:'], args));
        this._ensureLayoutBeforeDraw();
        if (typeof args[0] === 'string') {
            this.context.clip(args[0]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D && typeof args[1] === 'string') {
            this.context.clip(args[0].native, args[1]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D) {
            this.context.clip(args[0].native);
        }
        else {
            this.context.clip();
        }
    };
    TNSCanvasRenderingContext2D.prototype.closePath = function () {
        this.log('closePath');
        this._ensureLayoutBeforeDraw();
        this.context.closePath();
    };
    TNSCanvasRenderingContext2D.prototype.createImageData = function (width, height) {
        this.log('createImageData value:', arguments);
        if (width instanceof ImageData_1.ImageData) {
            return ImageData_1.ImageData.from(width);
        }
        else {
            return ImageData_1.ImageData.fromNative(this.context.createImageData(width, height));
        }
    };
    TNSCanvasRenderingContext2D.prototype.createLinearGradient = function (x0, y0, x1, y1) {
        this.log('createLinearGradient value:', x0, y0, x1, y1);
        this._ensureLayoutBeforeDraw();
        return CanvasGradient_1.CanvasGradient.fromNative(this.context.createLinearGradient(x0, y0, x1, y1));
    };
    TNSCanvasRenderingContext2D.prototype.createPattern = function (image, repetition) {
        this.log('createPattern value:', image, repetition);
        this._ensureLayoutBeforeDraw();
        if (repetition === undefined || typeof repetition !== 'string') {
            var e = new Error('The string did not match the expected pattern.');
            e.name = 'SyntaxError';
            throw e;
        }
        var img;
        if (image instanceof image_source_1.ImageSource) {
            img = image.android;
        }
        else if (image instanceof android.graphics.Bitmap) {
            img = image;
        }
        else if (image instanceof TNSImageAsset_1.TNSImageAsset) {
            img = image.native;
        }
        else if (image instanceof TNSCanvas_1.TNSCanvas) {
            img = image.android;
        }
        else if (image && typeof image.tagName === 'string' && image.tagName === 'IMG') {
            if (image._imageSource instanceof image_source_1.ImageSource) {
                img = image._imageSource.android;
            }
            else if (image._image instanceof android.graphics.Bitmap) {
                img = image._image;
            }
            else if (image._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                img = image._asset.native;
            }
            else if (typeof image.src === 'string') {
                img = image_source_1.ImageSource.fromFileSync(image.src).android;
            }
        }
        else if (image &&
            typeof image.tagName === 'string' &&
            image.tagName === 'CANVAS' && image._canvas instanceof TNSCanvas_1.TNSCanvas) {
            img = image._canvas.android;
        }
        if (!img) {
            return null;
        }
        var rep;
        switch (repetition) {
            case 'no-repeat':
                rep = com.github.triniwiz.canvas.Pattern.PatternRepetition.NoRepeat;
                break;
            case 'repeat-x':
                rep = com.github.triniwiz.canvas.Pattern.PatternRepetition.RepeatX;
                break;
            case 'repeat-y':
                rep = com.github.triniwiz.canvas.Pattern.PatternRepetition.RepeatY;
                break;
            default:
                rep = com.github.triniwiz.canvas.Pattern.PatternRepetition.Repeat;
                break;
        }
        return new CanvasPattern_1.CanvasPattern(this.context.createPattern(img, rep));
    };
    TNSCanvasRenderingContext2D.prototype.createRadialGradient = function (x0, y0, r0, x1, y1, r1) {
        this.log('createRadialGradient value:', x0, y0, r0, x1, y1, r1);
        this._ensureLayoutBeforeDraw();
        return CanvasGradient_1.CanvasGradient.fromNative(this.context.createRadialGradient(x0, y0, r0, x1, y1, r1));
    };
    TNSCanvasRenderingContext2D.prototype.drawFocusIfNeeded = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
    };
    TNSCanvasRenderingContext2D.prototype.drawImage = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['drawImage value:'], args));
        this._ensureLayoutBeforeDraw();
        var image = args[0];
        if (image instanceof TNSImageAsset_1.TNSImageAsset) {
            image = image.native;
        }
        else if (image instanceof image_source_1.ImageSource) {
            image = image.android;
        }
        else if (image instanceof android.graphics.Bitmap) {
            image = image;
        }
        else if (image instanceof TNSCanvas_1.TNSCanvas) {
            image = image.android;
        }
        else if (image && typeof image.tagName === 'string' && image.tagName === 'IMG') {
            if (image._imageSource instanceof image_source_1.ImageSource) {
                image = image._imageSource.android;
            }
            else if (image._image instanceof android.graphics.Bitmap) {
                image = image._image;
            }
            else if (image._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                image = image._asset.native;
            }
            else if (typeof image.src === 'string') {
                image = image_source_1.ImageSource.fromFileSync(image.src).android;
            }
        }
        else if (image &&
            typeof image.tagName === 'string' &&
            image.tagName === 'CANVAS' && image._canvas instanceof TNSCanvas_1.TNSCanvas) {
            image = image._canvas.android;
        }
        if (args.length === 3) {
            this.context.drawImage(image, args[1], args[2]);
        }
        else if (args.length === 5) {
            this.context.drawImage(image, args[1], args[2], args[3], args[4]);
        }
        else if (args.length === 9) {
            this.context.drawImage(image, args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8]);
        }
    };
    TNSCanvasRenderingContext2D.prototype.ellipse = function (x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.log('ellipse value:', x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise);
        this._ensureLayoutBeforeDraw();
        this.context.ellipse(x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise);
    };
    TNSCanvasRenderingContext2D.prototype.fill = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['fill value:'], args));
        this._ensureLayoutBeforeDraw();
        if (typeof args[0] === 'string') {
            this.context.fill(args[0]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D && typeof args[1] === 'string') {
            this.context.fill(args[0].native, args[1]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D) {
            this.context.fill(args[0].native);
        }
        else {
            this.context.fill();
        }
    };
    TNSCanvasRenderingContext2D.prototype.fillRect = function (x, y, width, height) {
        this.log('fillRect value:', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.fillRect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.fillText = function (text, x, y, maxWidth) {
        this.log('fillText value:', text, x, y, maxWidth);
        this._ensureLayoutBeforeDraw();
        if (typeof maxWidth === 'number') {
            this.context.fillText(text, x, y, maxWidth);
        }
        else {
            this.context.fillText(text, x, y);
        }
    };
    TNSCanvasRenderingContext2D.prototype.getImageData = function (sx, sy, sw, sh) {
        this.log('getImageData value:', sx, sy, sw, sh);
        this._ensureLayoutBeforeDraw();
        return ImageData_1.ImageData.fromNative(this.context.getImageData(sx, sy, sw, sh));
    };
    TNSCanvasRenderingContext2D.prototype.getLineDash = function () {
        this.log('getLineDash');
        this._ensureLayoutBeforeDraw();
        return this.context.getLineDash();
    };
    TNSCanvasRenderingContext2D.prototype.isPointInPath = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['isPointInPath value:'], args));
        this._ensureLayoutBeforeDraw();
        if (args.length === 2) {
            return this.context.isPointInPath(args[0], args[1]);
        }
        else if (args.length === 3) {
            return this.context.isPointInPath(args[0], args[1], args[2]);
        }
        else if (args.length === 4 && args[0] instanceof TNSPath2D_1.TNSPath2D) {
            return this.context.isPointInPath(args[0].native, args[1], args[2], args[3]);
        }
        return false;
    };
    TNSCanvasRenderingContext2D.prototype.isPointInStroke = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['isPointInStroke value:'], args));
        this._ensureLayoutBeforeDraw();
        if (args.length === 2) {
            return this.context.isPointInStroke(args[0], args[1]);
        }
        else if (args.length === 3 && args[0] instanceof TNSPath2D_1.TNSPath2D) {
            return this.context.isPointInStroke(args[0].native, args[1], args[2]);
        }
        return false;
    };
    TNSCanvasRenderingContext2D.prototype.lineTo = function (x, y) {
        this.log('lineTo value:', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.lineTo(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.measureText = function (text) {
        this.log('measureText value:', text);
        this._ensureLayoutBeforeDraw();
        return new TextMetrics_1.TextMetrics(this.context.measureText(text));
    };
    TNSCanvasRenderingContext2D.prototype.moveTo = function (x, y) {
        this.log('moveTo value:', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.moveTo(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.putImageData = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['putImageData value:'], args));
        this._ensureLayoutBeforeDraw();
        if (!args) {
            return;
        }
        var data = args[0];
        if (args.length === 1) {
            data.native.updateData(Array.from(data.data));
            this.context.putImageData(data.native);
        }
        else if (args.length === 3) {
            data.native.updateData(Array.from(data.data));
            this.context.putImageData(data.native, args[1], args[2]);
        }
        else if (args.length === 7) {
            data.native.updateData(Array.from(data.data));
            this.context.putImageData(data.native, args[1], args[2], args[3], args[4], args[5], args[6]);
        }
    };
    TNSCanvasRenderingContext2D.prototype.quadraticCurveTo = function (cpx, cpy, x, y) {
        this.log('quadraticCurveTo value:', cpx, cpy, x, y);
        this._ensureLayoutBeforeDraw();
        this.context.quadraticCurveTo(cpx, cpy, x, y);
    };
    TNSCanvasRenderingContext2D.prototype.rect = function (x, y, width, height) {
        this.log('rect value:', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.rect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.removeHitRegion = function (id) {
    };
    TNSCanvasRenderingContext2D.prototype.resetTransform = function () {
        this.log('resetTransform value:');
        this._ensureLayoutBeforeDraw();
        this.context.resetTransform();
    };
    TNSCanvasRenderingContext2D.prototype.restore = function () {
        this.log('restore');
        this._ensureLayoutBeforeDraw();
        this.context.restore();
    };
    TNSCanvasRenderingContext2D.prototype.rotate = function (angle) {
        this.log('rotate value:', angle);
        this._ensureLayoutBeforeDraw();
        this.context.rotate(angle);
    };
    TNSCanvasRenderingContext2D.prototype.save = function () {
        this.log('save');
        this._ensureLayoutBeforeDraw();
        this.context.save();
    };
    TNSCanvasRenderingContext2D.prototype.scale = function (x, y) {
        this.log('scale value:', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.scale(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.scrollPathIntoView = function (path) {
    };
    TNSCanvasRenderingContext2D.prototype.setLineDash = function (segments) {
        this.log('setLineDash value:', segments);
        this._ensureLayoutBeforeDraw();
        this.context.setLineDash(segments);
    };
    TNSCanvasRenderingContext2D.prototype.setTransform = function (a, b, c, d, e, f) {
        this.log('setTransform value:', a, b, c, d, e, f);
        this._ensureLayoutBeforeDraw();
        this.context.setTransform(a, b, c, d, e, f);
    };
    TNSCanvasRenderingContext2D.prototype.stroke = function (path) {
        this.log('stroke value:', path);
        this._ensureLayoutBeforeDraw();
        if (path) {
            this.context.stroke(path.native);
        }
        else {
            this.context.stroke();
        }
    };
    TNSCanvasRenderingContext2D.prototype.strokeRect = function (x, y, width, height) {
        this.log('strokeRect value:', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.strokeRect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.strokeText = function (text, x, y, maxWidth) {
        this.log('strokeText value:', text, x, y, maxWidth);
        this._ensureLayoutBeforeDraw();
        if (typeof maxWidth === 'number') {
            this.context.strokeText(text, x, y, maxWidth);
        }
        else {
            this.context.strokeText(text, x, y);
        }
    };
    TNSCanvasRenderingContext2D.prototype.transform = function (a, b, c, d, e, f) {
        this.log('transform value:', a, b, c, d, e, f);
        this._ensureLayoutBeforeDraw();
        this.context.transform(a, b, c, d, e, f);
    };
    TNSCanvasRenderingContext2D.prototype.translate = function (x, y) {
        this.log('translate value:', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.translate(x, y);
    };
    TNSCanvasRenderingContext2D.prototype._ensureLayoutBeforeDraw = function () {
        if (this.canvas) {
            this.canvas._layoutNative();
        }
    };
    TNSCanvasRenderingContext2D.prototype.log = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        if (!TNSCanvasRenderingContext2D.isDebug) {
            return;
        }
        console.log(message, args);
    };
    TNSCanvasRenderingContext2D.isDebug = false;
    TNSCanvasRenderingContext2D.colorCache = {};
    return TNSCanvasRenderingContext2D;
}(canvas_plugin_common_1.TNSCanvasRenderingContext2DBase));
exports.TNSCanvasRenderingContext2D = TNSCanvasRenderingContext2D;
//# sourceMappingURL=TNSCanvasRenderingContext2D.android.js.map