"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var CanvasGradient_1 = require("./CanvasGradient");
var ColorHelper_1 = require("./ColorHelper");
var TNSPath2D_1 = require("./TNSPath2D");
var image_source_1 = require("@nativescript/core/image-source");
var ImageData_1 = require("./ImageData");
var TextMetrics_1 = require("./TextMetrics");
var color_1 = require("@nativescript/core/color");
var TNSImageAsset_1 = require("./TNSImageAsset");
var CanvasPattern_1 = require("./CanvasPattern");
var TNSCanvas_1 = require("./TNSCanvas");
var TNSCanvasRenderingContext2D = (function (_super) {
    __extends(TNSCanvasRenderingContext2D, _super);
    function TNSCanvasRenderingContext2D(context) {
        var _this = _super.call(this) || this;
        _this._shadowColor = 'transparent';
        _this._fillStyle = 'black';
        _this._strokeStyle = 'black';
        _this.context = context;
        return _this;
    }
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "native", {
        get: function () {
            return this.context;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "canvas", {
        get: function () {
            return this._canvas;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "font", {
        get: function () {
            this.log('get font');
            return this.context.font;
        },
        set: function (value) {
            this.log('set font value:', value);
            if (this.context) {
                this.context.font = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowColor", {
        get: function () {
            this.log('get shadowColor');
            return this._shadowColor;
        },
        set: function (color) {
            this.log('set shadowColor', color);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                if (typeof color === 'string' && !isNaN(parseInt(color))) {
                    this.context.shadowColor = parseInt(color);
                }
                else {
                    this.context.shadowColor = new color_1.Color(color).argb;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "globalAlpha", {
        get: function () {
            this.log('get globalAlpha');
            return this.context.globalAlpha;
        },
        set: function (alpha) {
            this.log('set globalAlpha', alpha);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.globalAlpha = alpha;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "imageSmoothingEnabled", {
        get: function () {
            this.log('get imageSmoothingEnabled');
            return this.context.imageSmoothingEnabled;
        },
        set: function (enabled) {
            this.log('set imageSmoothingEnabled', enabled);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.imageSmoothingEnabled = enabled;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "imageSmoothingQuality", {
        get: function () {
            this.log('get imageSmoothingQuality');
            switch (this.context.imageSmoothingQuality) {
                case 1:
                    return 'medium';
                case 2:
                    return 'high';
                default:
                    return 'low';
            }
        },
        set: function (quality) {
            this.log('set imageSmoothingQuality', quality);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (quality) {
                    case 'high':
                        this.context.imageSmoothingQuality = 2;
                        break;
                    case 'medium':
                        this.context.imageSmoothingQuality = 1;
                        break;
                    default:
                        this.context.imageSmoothingQuality = 0;
                        break;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineDashOffset", {
        get: function () {
            this.log('get lineDashOffset');
            return this.context.lineDashOffset;
        },
        set: function (offset) {
            this.log('set lineDashOffset', offset);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.lineDashOffset = offset;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineJoin", {
        get: function () {
            this.log('get lineJoin');
            switch (this.context.lineJoin) {
                case 0:
                    return 'bevel';
                case 1:
                    return 'round';
                default:
                    return 'miter';
            }
        },
        set: function (join) {
            this.log('set lineJoin', join);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (join) {
                    case 'bevel':
                        this.context.lineJoin = 0;
                        break;
                    case 'round':
                        this.context.lineJoin = 1;
                        break;
                    default:
                        this.context.lineJoin = 2;
                        break;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineCap", {
        get: function () {
            this.log('get lineCap');
            switch (this.context.lineCap) {
                case 1:
                    return 'round';
                case 2:
                    return 'square';
                default:
                    return 'butt';
            }
        },
        set: function (cap) {
            this.log('set lineCap', cap);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (cap) {
                    case 'round':
                        this.context.lineCap = 1;
                        break;
                    case 'square':
                        this.context.lineCap = 2;
                        break;
                    default:
                        this.context.lineCap = 0;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "miterLimit", {
        get: function () {
            this.log('get miterLimit');
            return this.context.miterLimit;
        },
        set: function (limit) {
            this.log('set miterLimit', limit);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.miterLimit = limit;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowBlur", {
        get: function () {
            this.log('get shadowBlur');
            return this.context.shadowBlur;
        },
        set: function (blur) {
            this.log('set shadowBlur', blur);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.shadowBlur = blur;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowOffsetX", {
        get: function () {
            this.log('get shadowOffsetX');
            return this.context.shadowOffsetX;
        },
        set: function (x) {
            this.log('set shadowOffsetX', x);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.shadowOffsetX = x;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "shadowOffsetY", {
        get: function () {
            this.log('get shadowOffsetY');
            return this.context.shadowOffsetY;
        },
        set: function (y) {
            this.log('set shadowOffsetY', y);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.shadowOffsetY = y;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "textAlign", {
        get: function () {
            this.log('get textAlign');
            switch (this.context.textAlign) {
                case 1:
                    return 'start';
                case 2:
                    return 'center';
                case 3:
                    return 'end';
                case 4:
                    return 'right';
                default:
                    return 'left';
            }
        },
        set: function (alignment) {
            this.log('set textAlign', alignment);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (alignment) {
                    case 'start':
                        this.context.textAlign = 1;
                        break;
                    case 'center':
                        this.context.textAlign = 2;
                        break;
                    case 'end':
                        this.context.textAlign = 3;
                        break;
                    case 'right':
                        this.context.textAlign = 4;
                        break;
                    default:
                        this.context.textAlign = 0;
                        break;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "globalCompositeOperation", {
        get: function () {
            this.log('get globalCompositeOperation');
            switch (this.context.globalCompositeOperation) {
                case 0:
                    return 'source-over';
                case 1:
                    return 'source-in';
                case 2:
                    return 'source-out';
                case 3:
                    return 'source-atop';
                case 4:
                    return 'destination-over';
                case 5:
                    return 'destination-in';
                case 6:
                    return 'destination-out';
                case 7:
                    return 'destination-atop';
                case 8:
                    return 'lighter';
                case 9:
                    return 'copy';
                case 10:
                    return 'xor';
                case 11:
                    return 'multiply';
                case 12:
                    return 'screen';
                case 13:
                    return 'overlay';
                case 14:
                    return 'darken';
                case 15:
                    return 'lighten';
                case 16:
                    return 'color-dodge';
                case 17:
                    return 'color-burn';
                case 18:
                    return 'hard-light';
                case 19:
                    return 'soft-light';
                case 20:
                    return 'difference';
                case 21:
                    return 'exclusion';
                case 22:
                    return 'hue';
                case 23:
                    return 'saturation';
                case 24:
                    return 'color';
                case 25:
                    return 'luminosity';
                default:
                    return 'source-over';
            }
        },
        set: function (composite) {
            this.log('set globalCompositeOperation', composite);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                switch (composite.toLowerCase()) {
                    case 'source-over':
                        this.context.globalCompositeOperation = 0;
                        break;
                    case 'source-in':
                        this.context.globalCompositeOperation = 1;
                        break;
                    case 'source-out':
                        this.context.globalCompositeOperation = 2;
                        break;
                    case 'source-atop':
                        this.context.globalCompositeOperation = 3;
                        break;
                    case 'destination-over':
                        this.context.globalCompositeOperation = 4;
                        break;
                    case 'destination-in':
                        this.context.globalCompositeOperation = 5;
                        break;
                    case 'destination-out':
                        this.context.globalCompositeOperation = 6;
                        break;
                    case 'destination-atop':
                        this.context.globalCompositeOperation = 7;
                        break;
                    case 'lighter':
                        this.context.globalCompositeOperation = 8;
                        break;
                    case 'copy':
                        this.context.globalCompositeOperation = 9;
                        break;
                    case 'xor':
                        this.context.globalCompositeOperation = 10;
                        break;
                    case 'multiply':
                        this.context.globalCompositeOperation = 11;
                        break;
                    case 'screen':
                        this.context.globalCompositeOperation = 12;
                        break;
                    case 'overlay':
                        this.context.globalCompositeOperation = 13;
                        break;
                    case 'darken':
                        this.context.globalCompositeOperation = 14;
                        break;
                    case 'lighten':
                        this.context.globalCompositeOperation = 15;
                        break;
                    case 'color-dodge':
                        this.context.globalCompositeOperation = 16;
                        break;
                    case 'color-burn':
                        this.context.globalCompositeOperation = 17;
                        break;
                    case 'hard-light':
                        this.context.globalCompositeOperation = 18;
                        break;
                    case 'soft-light':
                        this.context.globalCompositeOperation = 19;
                        break;
                    case 'difference':
                        this.context.globalCompositeOperation = 20;
                        break;
                    case 'exclusion':
                        this.context.globalCompositeOperation = 21;
                        break;
                    case 'hue':
                        this.context.globalCompositeOperation = 22;
                        break;
                    case 'saturation':
                        this.context.globalCompositeOperation = 23;
                        break;
                    case 'color':
                        this.context.globalCompositeOperation = 24;
                        break;
                    case 'luminosity':
                        this.context.globalCompositeOperation = 25;
                        break;
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "fillStyle", {
        get: function () {
            this.log('get fillStyle');
            return this._fillStyle;
        },
        set: function (color) {
            this.log('set fillStyle', color);
            this._ensureLayoutBeforeDraw();
            if (this._fillStyle === color) {
                return;
            }
            var nativeStyle;
            if (color instanceof CanvasGradient_1.CanvasGradient) {
                this._fillStyle = color;
                nativeStyle = color.native;
            }
            else if (color instanceof CanvasPattern_1.CanvasPattern) {
                this._fillStyle = color;
                nativeStyle = color.native;
            }
            else if (color === undefined || color === null) {
                color = 'black';
            }
            else {
                var wasHsl = false;
                if (typeof color === 'string' && color.startsWith('hsla')) {
                    wasHsl = true;
                    color = ColorHelper_1.ColorHandler.HSLAToRGBA(color, false);
                }
                else if (typeof color === 'string' && color.startsWith('hsl')) {
                    wasHsl = true;
                    color = ColorHelper_1.ColorHandler.HSLToRGB(color, false);
                }
                if (typeof color === 'string' &&
                    color.indexOf('Invalid input color') > -1) {
                    color = 'black';
                }
                this._fillStyle = color;
                nativeStyle = new color_1.Color(color).argb;
            }
            this.context.fillStyle = nativeStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "strokeStyle", {
        get: function () {
            this.log('get strokeStyle');
            return this._strokeStyle;
        },
        set: function (color) {
            this.log('set strokeStyle', color);
            this._ensureLayoutBeforeDraw();
            if (this.strokeStyle === color) {
                return;
            }
            var nativeStyle;
            if (color instanceof CanvasGradient_1.CanvasGradient) {
                nativeStyle = color.native;
                this._strokeStyle = color;
            }
            else if (color instanceof CanvasPattern_1.CanvasPattern) {
                this._strokeStyle = color;
                nativeStyle = color.native;
            }
            else if (color === undefined || color === null) {
                color = 'black';
            }
            else {
                if (color.startsWith('hsla')) {
                    color = ColorHelper_1.ColorHandler.HSLAToRGBA(color, false);
                }
                else if (color.startsWith('hsl')) {
                    color = ColorHelper_1.ColorHandler.HSLToRGB(color, false);
                }
                if (typeof color === 'string' &&
                    color.indexOf('Invalid input color') > -1) {
                    color = 'black';
                }
                this._strokeStyle = color;
                nativeStyle = new color_1.Color(color).argb;
            }
            this.context.strokeStyle = nativeStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2D.prototype, "lineWidth", {
        get: function () {
            this.log('get lineWidth');
            return this.context.lineWidth;
        },
        set: function (width) {
            this.log('set lineWidth', width);
            this._ensureLayoutBeforeDraw();
            if (this.context) {
                this.context.lineWidth = width;
            }
        },
        enumerable: true,
        configurable: true
    });
    TNSCanvasRenderingContext2D.prototype.addHitRegion = function (region) {
    };
    TNSCanvasRenderingContext2D.prototype.arc = function (x, y, radius, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.log('arc', x, y, radius, startAngle, anticlockwise);
        this._ensureLayoutBeforeDraw();
        this.context.arc(x, y, radius, startAngle, endAngle, anticlockwise);
    };
    TNSCanvasRenderingContext2D.prototype.arcTo = function (x1, y1, x2, y2, radius) {
        this.log('arcTo', x1, y1, x2, y2, radius);
        this._ensureLayoutBeforeDraw();
        this.context.arcTo(x1, y1, x2, y2, radius);
    };
    TNSCanvasRenderingContext2D.prototype.beginPath = function () {
        this.log('beginPath');
        this._ensureLayoutBeforeDraw();
        this.context.beginPath();
    };
    TNSCanvasRenderingContext2D.prototype.bezierCurveTo = function (cp1x, cp1y, cp2x, cp2y, x, y) {
        this.log('bezierCurveTo', cp1x, cp1y, cp2x, cp2y, x, y);
        this._ensureLayoutBeforeDraw();
        this.context.bezierCurveTo(cp1x, cp1y, cp2x, cp2y, x, y);
    };
    TNSCanvasRenderingContext2D.prototype.clearHitRegions = function () {
    };
    TNSCanvasRenderingContext2D.prototype.clearRect = function (x, y, width, height) {
        this.log('clearRect', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.clearRect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.clip = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['clip'], args));
        this._ensureLayoutBeforeDraw();
        if (typeof args[0] === 'string') {
            this.context.clip(args[0]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D && typeof args[1] === 'string') {
            this.context.clip(args[0].native, args[1]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D) {
            this.context.clip(args[0].native);
        }
        else {
            this.context.clip();
        }
    };
    TNSCanvasRenderingContext2D.prototype.closePath = function () {
        this.log('closePath');
        this._ensureLayoutBeforeDraw();
        this.context.closePath();
    };
    TNSCanvasRenderingContext2D.prototype.createImageData = function (width, height) {
        this.log('createImageData', width, height);
        if (width instanceof ImageData_1.ImageData) {
            return ImageData_1.ImageData.fromNative(this.context.createImageData(width.native));
        }
        else {
            return ImageData_1.ImageData.fromNative(this.context.createImageData(width, height));
        }
    };
    TNSCanvasRenderingContext2D.prototype.createLinearGradient = function (x0, y0, x1, y1) {
        this.log('createLinearGradient', x0, y0, x1, y1);
        this._ensureLayoutBeforeDraw();
        return CanvasGradient_1.CanvasGradient.fromNative(this.context.createLinearGradient(x0, y0, x1, y1));
    };
    TNSCanvasRenderingContext2D.prototype.createPattern = function (image, repetition) {
        this.log('createPattern', image, repetition);
        this._ensureLayoutBeforeDraw();
        if (repetition === undefined || typeof repetition !== 'string') {
            var e = new Error('The string did not match the expected pattern.');
            e.name = 'SyntaxError';
            throw e;
        }
        var img;
        if (image instanceof image_source_1.ImageSource) {
            img = image.ios;
        }
        else if (image instanceof UIImage) {
            img = image;
        }
        else if (image instanceof TNSImageAsset_1.TNSImageAsset) {
            img = image.native;
        }
        else if (image instanceof TNSCanvas_1.TNSCanvas) {
            img = image.ios;
        }
        else if (image && typeof image.tagName === 'string' && image.tagName === 'IMG') {
            if (image._imageSource instanceof image_source_1.ImageSource) {
                img = image._imageSource.android;
            }
            else if (image._image instanceof UIImage) {
                img = image._image;
            }
            else if (image._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                img = image._asset.native;
            }
            else if (typeof image.src === 'string') {
                img = image_source_1.ImageSource.fromFileSync(image.src).ios;
            }
        }
        else if (image &&
            typeof image.tagName === 'string' &&
            image.tagName === 'CANVAS') {
            if (image._canvas instanceof TNSCanvas_1.TNSCanvas) {
                img = image._canvas.ios;
            }
        }
        if (!img) {
            return null;
        }
        var rep;
        switch (repetition) {
            case 'no-repeat':
                rep = 3;
                break;
            case 'repeat-x':
                rep = 1;
                break;
            case 'repeat-y':
                rep = 2;
                break;
            default:
                rep = 0;
                break;
        }
        if (img instanceof ImageAsset) {
            return new CanvasPattern_1.CanvasPattern(this.context.createPattern(img, rep));
        }
        else if (img instanceof UIImage) {
            return new CanvasPattern_1.CanvasPattern(this.context.createPattern(img, rep));
        }
        else if (img instanceof Canvas) {
            return new CanvasPattern_1.CanvasPattern(this.context.createPattern(img, rep));
        }
        return null;
    };
    TNSCanvasRenderingContext2D.prototype.createRadialGradient = function (x0, y0, r0, x1, y1, r1) {
        this.log('createRadialGradient', x0, y0, r0, x1, y1, r1);
        this._ensureLayoutBeforeDraw();
        return CanvasGradient_1.CanvasGradient.fromNative(this.context.createRadialGradient(x0, y0, r0, x1, y1, r1));
    };
    TNSCanvasRenderingContext2D.prototype.drawFocusIfNeeded = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
    };
    TNSCanvasRenderingContext2D.prototype.drawImage = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['drawImage'], args));
        this._ensureLayoutBeforeDraw();
        if (!args) {
            return;
        }
        var image = args[0];
        var asset = null;
        var width = 0;
        var height = 0;
        if (image instanceof image_source_1.ImageSource) {
            image = image.ios;
        }
        else if (image instanceof TNSImageAsset_1.TNSImageAsset || image instanceof UIImage) {
        }
        else if (image &&
            typeof image.tagName === 'string' &&
            image.tagName === 'IMG') {
            width = image.width;
            height = image.height;
            if (image._imageSource instanceof image_source_1.ImageSource) {
                image = image._imageSource.ios;
            }
            else if (image._image instanceof UIImage) {
                image = image._image;
            }
            else if (image._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                image = image._asset;
            }
            else if (typeof image.src === 'string') {
                image = image_source_1.ImageSource.fromFileSync(image.src).ios;
            }
        }
        else if (image &&
            typeof image.tagName === 'string' &&
            image.tagName === 'CANVAS' && image._canvas instanceof TNSCanvas_1.TNSCanvas) {
            image = image._canvas;
        }
        if (args.length === 3) {
            if (image instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.drawImage(image.native, args[1], args[2]);
            }
            else if (image instanceof TNSCanvas_1.TNSCanvas) {
                this.context.drawImage(image.ios, args[1], args[2]);
            }
            else {
                this.context.drawImage(image, args[1], args[2]);
            }
        }
        else if (args.length === 5) {
            if (image instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.drawImage(image.native, args[1], args[2], args[3], args[4]);
            }
            else if (image instanceof TNSCanvas_1.TNSCanvas) {
                this.context.drawImage(image.ios, args[1], args[2], args[3], args[4]);
            }
            else {
                this.context.drawImage(image, args[1], args[2], args[3], args[4]);
            }
        }
        else if (args.length === 9) {
            if (image instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.drawImage(image.native, args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8]);
            }
            else if (image instanceof TNSCanvas_1.TNSCanvas) {
                this.context.drawImage(image.ios, args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8]);
            }
            else {
                this.context.drawImage(image, args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8]);
            }
        }
    };
    TNSCanvasRenderingContext2D.prototype.ellipse = function (x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise) {
        if (anticlockwise === void 0) { anticlockwise = false; }
        this.log('ellipse', x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise);
        this._ensureLayoutBeforeDraw();
        this.context.ellipse(x, y, radiusX, radiusY, rotation, startAngle, endAngle, anticlockwise);
    };
    TNSCanvasRenderingContext2D.prototype.fill = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['fill'], args));
        this._ensureLayoutBeforeDraw();
        if (typeof args[0] === 'string') {
            this.context.fill(args[0]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D && typeof args[1] === 'string') {
            this.context.fill(args[0].native, args[1]);
        }
        else if (args[0] instanceof TNSPath2D_1.TNSPath2D) {
            this.context.fill(args[0].native);
        }
        else {
            this.context.fill();
        }
    };
    TNSCanvasRenderingContext2D.prototype.fillRect = function (x, y, width, height) {
        this.log('fillRect', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.fillRect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.fillText = function (text, x, y, maxWidth) {
        this.log('fillText', text, x, y, maxWidth);
        this._ensureLayoutBeforeDraw();
        if (typeof maxWidth === 'number') {
            this.context.fillText(text, x, y, maxWidth);
        }
        else {
            this.context.fillText(text, x, y);
        }
    };
    TNSCanvasRenderingContext2D.prototype.getImageData = function (sx, sy, sw, sh) {
        this.log('getImageData', sx, sy, sw, sh);
        this._ensureLayoutBeforeDraw();
        return ImageData_1.ImageData.fromNative(this.context.getImageData(sx, sy, sw, sh));
    };
    TNSCanvasRenderingContext2D.prototype.getLineDash = function () {
        this.log('getLineDash');
        this._ensureLayoutBeforeDraw();
        return this.context.getLineDash();
    };
    TNSCanvasRenderingContext2D.prototype.isPointInPath = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['isPointInPath'], args));
        this._ensureLayoutBeforeDraw();
        if (args.length === 2) {
            return this.context.isPointInPath(args[0], args[1]);
        }
        else if (args.length === 3) {
            return this.context.isPointInPath(args[0], args[1], args[2]);
        }
        else if (args.length === 4 && args[0] instanceof TNSPath2D_1.TNSPath2D) {
            return this.context.isPointInPath(args[0].native, args[1], args[2], args[3]);
        }
        return false;
    };
    TNSCanvasRenderingContext2D.prototype.isPointInStroke = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['isPointInStroke'], args));
        this._ensureLayoutBeforeDraw();
        if (args.length === 2) {
            return this.context.isPointInStroke(args[0], args[1]);
        }
        else if (args.length === 3 && args[0] instanceof TNSPath2D_1.TNSPath2D) {
            return this.context.isPointInStroke(args[0].native, args[1], args[2]);
        }
        return false;
    };
    TNSCanvasRenderingContext2D.prototype.lineTo = function (x, y) {
        this.log('lineTo', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.lineTo(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.measureText = function (text) {
        this.log('measureText', text);
        this._ensureLayoutBeforeDraw();
        return new TextMetrics_1.TextMetrics(this.context.measureText(text));
    };
    TNSCanvasRenderingContext2D.prototype.moveTo = function (x, y) {
        this.log('moveTo', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.moveTo(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.putImageData = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spreadArrays(['putImageData'], args));
        this._ensureLayoutBeforeDraw();
        if (!args) {
            return;
        }
        var data = args[0];
        if (args.length === 3) {
            this.context.putImageData(data.native, args[1], args[2]);
        }
        else if (args.length === 7) {
            this.context.putImageData(data.native, args[1], args[2], args[3], args[4], args[5], args[6]);
        }
    };
    TNSCanvasRenderingContext2D.prototype.quadraticCurveTo = function (cpx, cpy, x, y) {
        this.log('quadraticCurveTo', cpx, cpy, x, y);
        this._ensureLayoutBeforeDraw();
        this.context.quadraticCurveTo(cpx, cpy, x, y);
    };
    TNSCanvasRenderingContext2D.prototype.rect = function (x, y, width, height) {
        this.log('rect', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.rect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.removeHitRegion = function (id) {
    };
    TNSCanvasRenderingContext2D.prototype.resetTransform = function () {
        this.log('resetTransform');
        this._ensureLayoutBeforeDraw();
        this.context.resetTransform();
    };
    TNSCanvasRenderingContext2D.prototype.restore = function () {
        this.log('restore');
        this._ensureLayoutBeforeDraw();
        this.context.restore();
    };
    TNSCanvasRenderingContext2D.prototype.rotate = function (angle) {
        this.log('rotate', angle);
        this._ensureLayoutBeforeDraw();
        this.context.rotate(angle);
    };
    TNSCanvasRenderingContext2D.prototype.save = function () {
        this.log('save');
        this._ensureLayoutBeforeDraw();
        this.context.save();
    };
    TNSCanvasRenderingContext2D.prototype.scale = function (x, y) {
        this.log('scale', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.scale(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.scrollPathIntoView = function (path) {
    };
    TNSCanvasRenderingContext2D.prototype.setLineDash = function (segments) {
        this.log('setLineDash', segments);
        this._ensureLayoutBeforeDraw();
        this.context.setLineDash(segments);
    };
    TNSCanvasRenderingContext2D.prototype.setTransform = function (a, b, c, d, e, f) {
        this.log('setTransform', a, b, c, d, e, f);
        this._ensureLayoutBeforeDraw();
        this.context.setTransform(a, b, c, d, e, f);
    };
    TNSCanvasRenderingContext2D.prototype.stroke = function (path) {
        this.log('stroke', path);
        this._ensureLayoutBeforeDraw();
        if (path) {
            this.context.stroke(path.native);
        }
        else {
            this.context.stroke();
        }
    };
    TNSCanvasRenderingContext2D.prototype.strokeRect = function (x, y, width, height) {
        this.log('strokeRect', x, y, width, height);
        this._ensureLayoutBeforeDraw();
        this.context.strokeRect(x, y, width, height);
    };
    TNSCanvasRenderingContext2D.prototype.strokeText = function (text, x, y, maxWidth) {
        this.log('strokeText', text, x, y, maxWidth);
        this._ensureLayoutBeforeDraw();
        if (typeof maxWidth === 'number') {
            this.context.strokeText(text, x, y, maxWidth);
        }
        else {
            this.context.strokeText(text, x, y);
        }
    };
    TNSCanvasRenderingContext2D.prototype.transform = function (a, b, c, d, e, f) {
        this.log('transform', a, b, c, d, e, f);
        this._ensureLayoutBeforeDraw();
        this.context.transform(a, b, c, d, e, f);
    };
    TNSCanvasRenderingContext2D.prototype.translate = function (x, y) {
        this.log('translate', x, y);
        this._ensureLayoutBeforeDraw();
        this.context.translate(x, y);
    };
    TNSCanvasRenderingContext2D.prototype.log = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        if (!TNSCanvasRenderingContext2D.isDebug) {
            return;
        }
        console.log(message, args);
    };
    TNSCanvasRenderingContext2D.prototype._ensureLayoutBeforeDraw = function () {
        if (this.canvas) {
            this.canvas._layoutNative();
        }
    };
    TNSCanvasRenderingContext2D.isDebug = false;
    return TNSCanvasRenderingContext2D;
}(canvas_plugin_common_1.TNSCanvasRenderingContext2DBase));
exports.TNSCanvasRenderingContext2D = TNSCanvasRenderingContext2D;
//# sourceMappingURL=TNSCanvasRenderingContext2D.ios.js.map