"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var TNSImageAsset_1 = require("./TNSImageAsset");
var image_source_1 = require("@nativescript/core/image-source/image-source");
var TNSWebGL2RenderingContextBase_1 = require("./TNSWebGL2RenderingContextBase");
var TNSWebGL2RenderingContext = (function (_super) {
    __extends(TNSWebGL2RenderingContext, _super);
    function TNSWebGL2RenderingContext(context) {
        return _super.call(this, context) || this;
    }
    TNSWebGL2RenderingContext.toPrimitive = function (value) {
        if (value instanceof java.lang.Integer) {
            return value.intValue();
        }
        else if (value instanceof java.lang.Long) {
            return value.longValue();
        }
        else if (value instanceof java.lang.Short) {
            return value.shortValue();
        }
        else if (value instanceof java.lang.Byte) {
            return value.byteValue();
        }
        else if (value instanceof java.lang.Boolean) {
            return value.booleanValue();
        }
        else if (value instanceof java.lang.String) {
            return value.toString();
        }
        else if (value instanceof java.lang.Float) {
            return value.floatValue();
        }
        else if (value instanceof java.lang.Double) {
            return value.doubleValue();
        }
        return value;
    };
    TNSWebGL2RenderingContext.prototype.beginQuery = function (target, query) {
        this._glCheckError('beginQuery');
        var value = query ? query.native : 0;
        this.native.beginQuery(target, value);
    };
    TNSWebGL2RenderingContext.prototype.beginTransformFeedback = function (primitiveMode) {
        this._glCheckError('beginTransformFeedback');
        this.native.beginTransformFeedback(primitiveMode);
    };
    TNSWebGL2RenderingContext.prototype.bindBufferBase = function (target, index, buffer) {
        this._glCheckError('bindBufferBase');
        var value = buffer ? buffer.native : 0;
        this.native.bindBufferBase(target, index, value);
    };
    TNSWebGL2RenderingContext.prototype.bindBufferRange = function (target, index, buffer, offset, size) {
        this._glCheckError('bindBufferRange');
        var value = buffer ? buffer.native : 0;
        this.native.bindBufferRange(target, index, value, offset, size);
    };
    TNSWebGL2RenderingContext.prototype.bindSampler = function (unit, sampler) {
        this._glCheckError('bindSampler');
        var value = sampler ? sampler.native : 0;
        this.native.bindSampler(unit, value);
    };
    TNSWebGL2RenderingContext.prototype.bindTransformFeedback = function (target, transformFeedback) {
        this._glCheckError('bindTransformFeedback');
        var value = transformFeedback ? transformFeedback.native : 0;
        this.native.bindTransformFeedback(target, value);
    };
    TNSWebGL2RenderingContext.prototype.bindVertexArray = function (vertexArray) {
        this._glCheckError('bindVertexArray');
        var value = vertexArray ? vertexArray.native : 0;
        this.native.bindVertexArray(value);
    };
    TNSWebGL2RenderingContext.prototype.blitFramebuffer = function (srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter) {
        this._glCheckError('blitFramebuffer');
        this.native.blitFramebuffer(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferfi = function (buffer, drawbuffer, depth, stencil) {
        this._glCheckError('clearBufferfi');
        var value = buffer ? buffer.native : 0;
        this.native.clearBufferfi(value, drawbuffer, depth, stencil);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferfv = function (buffer, drawbuffer, values) {
        this._glCheckError('clearBufferfv');
        var value = buffer ? buffer.native : 0;
        if (values instanceof Float32Array) {
            values = this.toNativeArray(values, 'float');
        }
        this.native.clearBufferfv(value, drawbuffer, values);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferiv = function (buffer, drawbuffer, values) {
        this._glCheckError('clearBufferiv');
        var value = buffer ? buffer.native : 0;
        if (values instanceof Int32Array) {
            values = this.toNativeArray(values, 'int');
        }
        this.native.clearBufferiv(value, drawbuffer, values);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferuiv = function (buffer, drawbuffer, values) {
        this._glCheckError('clearBufferuiv');
        var value = buffer ? buffer.native : 0;
        if (values instanceof Uint32Array) {
            values = this.toNativeArray(values, 'int');
        }
        this.native.clearBufferuiv(value, drawbuffer, values);
    };
    TNSWebGL2RenderingContext.prototype.clientWaitSync = function (sync, flags, timeout) {
        this._glCheckError('clientWaitSync');
        var value = sync ? sync.native : 0;
        return this.native.clientWaitSync(value, flags, timeout);
    };
    TNSWebGL2RenderingContext.prototype.compressedTexSubImage3D = function (target, level, xoffset, yoffset, zoffset, width, height, depth, format, srcData, srcOffset, srcLengthOverride) {
        if (srcOffset === void 0) { srcOffset = 0; }
        if (srcLengthOverride === void 0) { srcLengthOverride = 0; }
        this._glCheckError('compressedTexSubImage3D');
        if (typeof srcOffset === 'number') {
            this.native.compressedTexSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, srcData, srcOffset);
        }
        else if (srcData && srcData.buffer) {
            if (srcData instanceof Uint8Array) {
                this.native.compressedTexSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, this.toNativeArray(srcData, 'byte'), srcOffset, srcLengthOverride);
            }
        }
    };
    TNSWebGL2RenderingContext.prototype.copyBufferSubData = function (readTarget, writeTarget, readOffset, writeOffset, size) {
        this._glCheckError('copyBufferSubData');
        this.native.copyBufferSubData(readTarget, writeTarget, readOffset, writeOffset, size);
    };
    TNSWebGL2RenderingContext.prototype.copyTexSubImage3D = function (target, level, xoffset, yoffset, zoffset, x, y, width, height) {
        this._glCheckError('copyTexSubImage3D');
        this.native.copyTexSubImage3D(target, level, xoffset, yoffset, zoffset, x, y, width, height);
    };
    TNSWebGL2RenderingContext.prototype.createQuery = function () {
        this._glCheckError('createQuery');
        return new canvas_plugin_common_1.WebGLQuery(this.native.createQuery());
    };
    TNSWebGL2RenderingContext.prototype.createSampler = function () {
        this._glCheckError('createSampler');
        return new canvas_plugin_common_1.WebGLSampler(this.native.createSampler());
    };
    TNSWebGL2RenderingContext.prototype.createTransformFeedback = function () {
        this._glCheckError('createTransformFeedback');
        return new canvas_plugin_common_1.WebGLTransformFeedback(this.native.createTransformFeedback());
    };
    TNSWebGL2RenderingContext.prototype.createVertexArray = function () {
        this._glCheckError('createVertexArray');
        return new canvas_plugin_common_1.WebGLVertexArrayObject(this.native.createVertexArray());
    };
    TNSWebGL2RenderingContext.prototype.deleteQueryWithQuery = function (query) {
        this._glCheckError('deleteQueryWithQuery');
        var value = query ? query.native : 0;
        this.native.deleteQuery(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteSamplerWithSampler = function (sampler) {
        this._glCheckError('deleteSamplerWithSampler');
        var value = sampler ? sampler.native : 0;
        this.native.deleteSampler(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteSyncWithSync = function (sync) {
        this._glCheckError('deleteSyncWithSync');
        var value = sync ? sync.native : 0;
        this.native.deleteSync(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteTransformFeedback = function (transformFeedback) {
        this._glCheckError('deleteTransformFeedback');
        var value = transformFeedback ? transformFeedback.native : 0;
        this.native.deleteTransformFeedback(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteVertexArray = function (vertexArray) {
        this._glCheckError('deleteVertexArray');
        var value = vertexArray ? vertexArray.native : 0;
        this.native.deleteVertexArray(value);
    };
    TNSWebGL2RenderingContext.prototype.drawArraysInstanced = function (mode, first, count, instanceCount) {
        this._glCheckError('drawArraysInstanced');
        this.native.drawArraysInstanced(mode, first, count, instanceCount);
    };
    TNSWebGL2RenderingContext.prototype.drawBuffers = function (buffers) {
        this._glCheckError('drawBuffers');
        this.native.drawBuffers(buffers);
    };
    TNSWebGL2RenderingContext.prototype.drawElementsInstanced = function (mode, count, type, offset, instanceCount) {
        this._glCheckError('drawElementsInstanced');
        this.native.drawElementsInstanced(mode, count, type, offset, instanceCount);
    };
    TNSWebGL2RenderingContext.prototype.drawRangeElements = function (mode, start, end, count, type, offset) {
        this._glCheckError('drawRangeElements');
        this.native.drawRangeElements(mode, start, end, count, type, offset);
    };
    TNSWebGL2RenderingContext.prototype.endQuery = function (target) {
        this._glCheckError('endQuery');
        this.native.endQuery(target);
    };
    TNSWebGL2RenderingContext.prototype.endTransformFeedback = function () {
        this._glCheckError('endTransformFeedback');
        this.native.endTransformFeedback();
    };
    TNSWebGL2RenderingContext.prototype.fenceSync = function (condition, flags) {
        this._glCheckError('fenceSync');
        this.native.fenceSync(condition, flags);
    };
    TNSWebGL2RenderingContext.prototype.framebufferTextureLayer = function (target, attachment, texture, level, layer) {
        this._glCheckError('framebufferTextureLayer');
        var value = texture ? texture.native : 0;
        this.native.framebufferTextureLayer(target, attachment, value, level, layer);
    };
    TNSWebGL2RenderingContext.prototype.getActiveUniformBlockName = function (program, uniformBlockIndex) {
        this._glCheckError('getActiveUniformBlockName');
        var value = program ? program.native : 0;
        return this.native.getActiveUniformBlockName(value, uniformBlockIndex);
    };
    TNSWebGL2RenderingContext.prototype.getActiveUniformBlockParameter = function (program, uniformBlockIndex, pname) {
        this._glCheckError('getActiveUniformBlockParameter');
        var value = program ? program.native : 0;
        var param = this.native.getActiveUniformBlockParameter(value, uniformBlockIndex, pname);
        if (pname === this.UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES) {
            return new Uint32Array(this.getJSArray(param));
        }
        return TNSWebGL2RenderingContext.toPrimitive(param);
    };
    TNSWebGL2RenderingContext.prototype.getActiveUniforms = function (program, uniformIndices, pname) {
        this._glCheckError('getActiveUniforms');
        var value = program ? program.native : 0;
        return this.getJSArray(this.native.getActiveUniforms(value, uniformIndices, pname));
    };
    TNSWebGL2RenderingContext.prototype.getBufferSubData = function (target, srcByteOffset, dstData, dstOffset, length) {
        if (dstOffset === void 0) { dstOffset = 0; }
        if (length === void 0) { length = 0; }
        this._glCheckError('getBufferSubData');
        this.native.getBufferSubData(target, srcByteOffset, new Uint8Array(dstData.slice(0)), dstOffset, length);
    };
    TNSWebGL2RenderingContext.prototype.getFragDataLocation = function (program, name) {
        this._glCheckError('getFragDataLocation');
        var value = program ? program.native : 0;
        var result = this.native.getFragDataLocation(value, name);
        return result !== -1 ? result : null;
    };
    TNSWebGL2RenderingContext.prototype.getIndexedParameter = function (target, index) {
        this._glCheckError('getIndexedParameter');
        var param = this.native.getIndexedParameter(target, index);
        if (target === this.TRANSFORM_FEEDBACK_BUFFER_BINDING ||
            target === this.UNIFORM_BUFFER_BINDING) {
            return new canvas_plugin_common_1.WebGLBuffer(param);
        }
        return TNSWebGL2RenderingContext.toPrimitive(param);
    };
    TNSWebGL2RenderingContext.prototype.getInternalformatParameter = function (target, internalformat, pname) {
        this._glCheckError('getInternalformatParameter');
        var param = this.native.getInternalformatParameter(target, internalformat, pname);
        if (pname === this.SAMPLES) {
            return new Int32Array(this.getJSArray(param));
        }
        return TNSWebGL2RenderingContext.toPrimitive(param);
    };
    TNSWebGL2RenderingContext.prototype.getQueryParameter = function (query, pname) {
        this._glCheckError('getQueryParameter');
        var value = query ? query.native : 0;
        var result = this.native.getQueryParameter(value, pname);
        if (result === 0) {
            return null;
        }
        return TNSWebGL2RenderingContext.toPrimitive(result);
    };
    TNSWebGL2RenderingContext.prototype.getQuery = function (target, pname) {
        this._glCheckError('getQuery');
        var query = this.native.getQuery(target, pname);
        if (query) {
            return new canvas_plugin_common_1.WebGLQuery(query);
        }
        return null;
    };
    TNSWebGL2RenderingContext.prototype.getSamplerParameter = function (sampler, pname) {
        this._glCheckError('getSamplerParameter');
        var value = sampler ? sampler.native : 0;
        return TNSWebGL2RenderingContext.toPrimitive(this.native.getSamplerParameter(value, pname));
    };
    TNSWebGL2RenderingContext.prototype.getSyncParameter = function (sync, pname) {
        this._glCheckError('getSyncParameter');
        var value = sync ? sync.native : 0;
        return TNSWebGL2RenderingContext.toPrimitive(this.native.getSyncParameter(value, pname));
    };
    TNSWebGL2RenderingContext.prototype.getTransformFeedbackVarying = function (program, index) {
        this._glCheckError('getTransformFeedbackVarying');
        var value = program ? program.native : 0;
        var info = this.native.getTransformFeedbackVarying(value, index);
        if (info) {
            return new canvas_plugin_common_1.WebGLActiveInfo(info.name, info.size, info.size);
        }
        return null;
    };
    TNSWebGL2RenderingContext.prototype.getUniformBlockIndex = function (program, uniformBlockName) {
        this._glCheckError('getUniformBlockIndex');
        var value = program ? program.native : 0;
        return this.native.getUniformBlockIndex(value, uniformBlockName);
    };
    TNSWebGL2RenderingContext.prototype.getUniformIndices = function (program, uniformNames) {
        this._glCheckError('getUniformIndices');
        var value = program ? program.native : 0;
        return this.getJSArray(this.native.getUniformIndices(value, uniformNames));
    };
    TNSWebGL2RenderingContext.prototype.invalidateFramebuffer = function (target, attachments) {
        this._glCheckError('invalidateFramebuffer');
        this.native.invalidateFramebuffer(target, attachments);
    };
    TNSWebGL2RenderingContext.prototype.invalidateSubFramebuffer = function (target, attachments, x, y, width, height) {
        this._glCheckError('invalidateSubFramebuffer');
        this.native.invalidateSubFramebuffer(target, attachments, x, y, width, height);
    };
    TNSWebGL2RenderingContext.prototype.isQuery = function (query) {
        this._glCheckError('isQuery');
        var value = query ? query.native : 0;
        return this.native.isQuery(value);
    };
    TNSWebGL2RenderingContext.prototype.isSampler = function (sampler) {
        this._glCheckError('isSampler');
        var value = sampler ? sampler.native : 0;
        return this.native.isSampler(value);
    };
    TNSWebGL2RenderingContext.prototype.isSync = function (sync) {
        this._glCheckError('isSync');
        var value = sync ? sync.native : 0;
        return this.native.isSync(value);
    };
    TNSWebGL2RenderingContext.prototype.isTransformFeedback = function (transformFeedback) {
        this._glCheckError('isTransformFeedback');
        var value = transformFeedback ? transformFeedback.native : 0;
        return this.native.isTransformFeedback(value);
    };
    TNSWebGL2RenderingContext.prototype.isVertexArray = function (vertexArray) {
        this._glCheckError('isVertexArray');
        var value = vertexArray ? vertexArray.native : 0;
        return this.native.isVertexArray(value);
    };
    TNSWebGL2RenderingContext.prototype.pauseTransformFeedback = function () {
        this._glCheckError('pauseTransformFeedback');
        this.native.pauseTransformFeedback();
    };
    TNSWebGL2RenderingContext.prototype.readBuffer = function (src) {
        this._glCheckError('readBuffer');
        this.native.readBuffer(src);
    };
    TNSWebGL2RenderingContext.prototype.renderbufferStorageMultisample = function (target, samples, internalFormat, width, height) {
        this._glCheckError('renderbufferStorageMultisample');
        this.native.renderbufferStorageMultisample(target, samples, internalFormat, width, height);
    };
    TNSWebGL2RenderingContext.prototype.resumeTransformFeedback = function () {
        this._glCheckError('resumeTransformFeedback');
        this.native.resumeTransformFeedback();
    };
    TNSWebGL2RenderingContext.prototype.samplerParameterf = function (sampler, pname, param) {
        this._glCheckError('samplerParameterf');
        var value = sampler ? sampler.native : 0;
        this.native.samplerParameterf(value, pname, param);
    };
    TNSWebGL2RenderingContext.prototype.samplerParameteri = function (sampler, pname, param) {
        this._glCheckError('samplerParameteri');
        var value = sampler ? sampler.native : 0;
        this.native.samplerParameteri(value, pname, param);
    };
    TNSWebGL2RenderingContext.prototype.texImage3D = function (target, level, internalformat, width, height, depth, border, format, type, source) {
        this._glCheckError('texImage3D');
        if (typeof source === 'number') {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source);
        }
        else if (source && source.buffer) {
            if (source instanceof Uint8Array) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, this.toNativeArray(source, 'byte'));
            }
        }
        else if (source instanceof android.graphics.Bitmap) {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source);
        }
        else if (source instanceof image_source_1.ImageSource) {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source.android);
        }
        else if (source instanceof TNSImageAsset_1.TNSImageAsset) {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source.native);
        }
        else if (source &&
            typeof source.tagName === 'string' &&
            (source.tagName === 'IMG' || source.tagName === 'IMAGE')) {
            if (source._imageSource instanceof image_source_1.ImageSource) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source._imageSource.android);
            }
            else if (source._image instanceof android.graphics.Bitmap) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source._image);
            }
            else if (source._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source._asset.native);
            }
            else if (typeof source.src === 'string') {
                var result = image_source_1.ImageSource.fromFileSync(source.src);
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, result ? result.android : null);
            }
        }
    };
    TNSWebGL2RenderingContext.prototype.texStorage2D = function (target, levels, internalformat, width, height) {
        this._glCheckError('texStorage2D');
        this.native.texStorage2D(target, levels, internalformat, width, height);
    };
    TNSWebGL2RenderingContext.prototype.texStorage3D = function (target, levels, internalformat, width, height, depth) {
        this._glCheckError('texStorage3D');
        this.native.texStorage3D(target, levels, internalformat, width, height, depth);
    };
    TNSWebGL2RenderingContext.prototype.texSubImage3D = function (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData, srcOffset) {
        if (srcOffset === void 0) { srcOffset = 0; }
        this._glCheckError('texSubImage3D');
        if (typeof srcData === 'number') {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData);
        }
        else if (srcData && srcData.buffer) {
            if (srcData instanceof Uint8Array) {
                if (srcOffset) {
                    this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, this.toNativeArray(srcData, 'byte'), srcOffset);
                }
                else {
                    this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, this.toNativeArray(srcData, 'byte'));
                }
            }
        }
        else if (srcData instanceof android.graphics.Bitmap) {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData);
        }
        else if (srcData instanceof image_source_1.ImageSource) {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData.android);
        }
        else if (srcData instanceof TNSImageAsset_1.TNSImageAsset) {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData.native);
        }
        else if (srcData &&
            typeof srcData.tagName === 'string' &&
            (srcData.tagName === 'IMG' || srcData.tagName === 'IMAGE')) {
            if (srcData._imageSource instanceof image_source_1.ImageSource) {
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData._imageSource.android);
            }
            else if (srcData._image instanceof android.graphics.Bitmap) {
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData._image);
            }
            else if (srcData._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData._asset.native);
            }
            else if (typeof srcData.src === 'string') {
                var result = image_source_1.ImageSource.fromFileSync(srcData.src);
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, result ? result.android : null);
            }
        }
    };
    TNSWebGL2RenderingContext.prototype.transformFeedbackVaryings = function (program, varyings, bufferMode) {
        this._glCheckError('transformFeedbackVaryings');
        var value = program ? program.native : 0;
        this.native.transformFeedbackVaryings(value, varyings, bufferMode);
    };
    TNSWebGL2RenderingContext.prototype.uniform1ui = function (location, v0) {
        this._glCheckError('uniform1ui');
        var value = location ? location.native : 0;
        this.native.uniform1ui(value, v0);
    };
    TNSWebGL2RenderingContext.prototype.uniform1uiv = function (location, data) {
        this._glCheckError('uniform1uiv');
        var value = location ? location.native : 0;
        this.native.uniform1uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniform2ui = function (location, v0, v1) {
        this._glCheckError('uniform2ui');
        var value = location ? location.native : 0;
        this.native.uniform2ui(value, v0, v1);
    };
    TNSWebGL2RenderingContext.prototype.uniform2uiv = function (location, data) {
        this._glCheckError('uniform2uiv');
        var value = location ? location.native : 0;
        this.native.uniform2uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniform3ui = function (location, v0, v1, v2) {
        this._glCheckError('uniform3ui');
        var value = location ? location.native : 0;
        this.native.uniform3ui(value, v0, v1, v2);
    };
    TNSWebGL2RenderingContext.prototype.uniform3uiv = function (location, data) {
        this._glCheckError('uniform3uiv');
        var value = location ? location.native : 0;
        this.native.uniform3uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniform4ui = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4ui');
        var value = location ? location.native : 0;
        this.native.uniform4ui(value, v0, v1, v2, v3);
    };
    TNSWebGL2RenderingContext.prototype.uniform4uiv = function (location, data) {
        this._glCheckError('uniform4uiv');
        var value = location ? location.native : 0;
        this.native.uniform4uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformBlockBinding = function (program, uniformBlockIndex, uniformBlockBinding) {
        this._glCheckError('uniformBlockBinding');
        var value = program ? program.native : 0;
        this.native.uniformBlockBinding(value, uniformBlockIndex, uniformBlockBinding);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix2x3fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix2x3fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix2x3fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix2x4fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix2x4fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix2x4fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix3x2fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix3x2fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix3x2fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix3x4fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix3x4fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix3x4fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix4x2fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix4x2fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix4x2fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix4x3fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix4x3fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix4x3fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribDivisor = function (index, divisor) {
        this._glCheckError('vertexAttribDivisor');
        this.native.vertexAttribDivisor(index, divisor);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4i = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttribI4i');
        this.native.vertexAttribI4i(index, v0, v1, v2, v3);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4iv = function (index, value) {
        if (value instanceof Int32Array) {
            value = this.toNativeArray(value, 'int');
        }
        this._glCheckError('vertexAttribI4iv');
        this.native.vertexAttribI4uiv(index, value);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4ui = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttribI4ui');
        this.native.vertexAttribI4ui(index, v0, v1, v2, v3);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4uiv = function (index, value) {
        if (value instanceof Uint32Array) {
            value = this.toNativeArray(value, 'int');
        }
        this._glCheckError('vertexAttribI4uiv');
        this.native.vertexAttribI4uiv(index, value);
    };
    TNSWebGL2RenderingContext.prototype._glCheckError = function (message) {
        if (!TNSWebGL2RenderingContext.isDebug) {
            return;
        }
        console.log(message, this.getError());
    };
    TNSWebGL2RenderingContext.isDebug = false;
    return TNSWebGL2RenderingContext;
}(TNSWebGL2RenderingContextBase_1.TNSWebGL2RenderingContextBase));
exports.TNSWebGL2RenderingContext = TNSWebGL2RenderingContext;
//# sourceMappingURL=TNSWebGL2RenderingContext.android.js.map