"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var view_1 = require("@nativescript/core/ui/core/view");
var gestures_1 = require("@nativescript/core/ui/gestures/gestures");
var platform_1 = require("@nativescript/core/platform");
var application_1 = require("@nativescript/core/application");
__export(require("@nativescript/core/ui/core/view"));
Set.prototype.remove = function (value) {
    this.delete(value);
};
var TNSCanvasBase = (function (_super) {
    __extends(TNSCanvasBase, _super);
    function TNSCanvasBase() {
        var _this = _super.call(this) || this;
        _this._isCustom = false;
        _this._touchEvents = _this._touchEventsFN.bind(_this);
        _this.on('touch, pan', _this._touchEvents);
        _this._classList = new Set();
        _this.on('layoutChanged', function (args) {
            if (_this.parent) {
                _this.parent['clientWidth'] = _this.parent.getMeasuredWidth();
                _this.parent['clientHeight'] = _this.parent.getMeasuredHeight();
            }
        });
        return _this;
    }
    Object.defineProperty(TNSCanvasBase.prototype, "classList", {
        get: function () {
            return this._classList;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasBase.prototype, "_realSize", {
        get: function () {
            return {
                width: this.getSize(this.style.width, this.getMeasuredWidth(), 'width'),
                height: this.getSize(this.style.height, this.getMeasuredHeight(), 'height'),
            };
        },
        enumerable: true,
        configurable: true
    });
    TNSCanvasBase.prototype._touchEventsFN = function (event) {
        if (event.eventName === 'touch') {
            switch (event.action) {
                case 'down':
                    this._emitEvent('touchstart', event);
                    break;
                case 'up':
                    this._emitEvent('touchend', event);
                    break;
                case 'cancel':
                    this._emitEvent('touchcancel', event);
                    break;
                case 'move':
                    break;
                default:
                    break;
            }
        }
        else if (event.eventName === 'pan') {
            if (event.state === gestures_1.GestureStateTypes.began ||
                event.state === gestures_1.GestureStateTypes.changed) {
                this._emitEvent('touchmove', event);
            }
        }
    };
    TNSCanvasBase.prototype._getTouchEvent = function (name, event, target) {
        var pointers = new TouchList();
        var scale = platform_1.screen.mainScreen.scale;
        var activePointer = {};
        if (name === 'touchmove') {
            activePointer = {
                clientX: event.deltaX * scale,
                clientY: event.deltaY * scale,
                force: 0.0,
                identifier: 0,
                pageX: event.deltaX * scale,
                pageY: event.deltaY * scale,
                radiusX: 0,
                radiusY: 0,
                rotationAngle: 0,
                screenX: event.deltaX * scale,
                screenY: event.deltaY * scale,
                target: target,
            };
            pointers.push({
                clientX: event.deltaX * scale,
                clientY: event.deltaY * scale,
                force: 0.0,
                identifier: 0,
                pageX: event.deltaX * scale,
                pageY: event.deltaY * scale,
                radiusX: 0,
                radiusY: 0,
                rotationAngle: 0,
                screenX: event.deltaX * scale,
                screenY: event.deltaY * scale,
                target: target,
            });
        }
        else {
            var count = event.getAllPointers().length;
            var point = event.getActivePointers()[0];
            activePointer = {
                clientX: point.getX() * scale,
                clientY: point.getY() * scale,
                force: 0.0,
                identifier: 0,
                pageX: point.getX() * scale,
                pageY: point.getY() * scale,
                radiusX: 0,
                radiusY: 0,
                rotationAngle: 0,
                screenX: point.getX() * scale,
                screenY: point.getY() * scale,
            };
            for (var i = 0; i < count; i++) {
                var point_1 = event.getAllPointers()[i];
                pointers.push({
                    clientX: point_1.getX(),
                    clientY: point_1.getY(),
                    force: 0.0,
                    identifier: i,
                    pageX: point_1.getX(),
                    pageY: point_1.getY(),
                    radiusX: 0,
                    radiusY: 0,
                    rotationAngle: 0,
                    screenX: point_1.getX(),
                    screenY: point_1.getY(),
                    target: target,
                });
            }
        }
        return __assign({ eventName: name, object: null, defaultPrevented: false, cancelable: false, altKey: false, changedTouches: pointers, ctrlKey: false, metaKey: false, shiftKey: false, targetTouches: pointers, touches: pointers, preventDefault: function () {
            }, target: target }, activePointer);
    };
    TNSCanvasBase.prototype._emitEvent = function (name, event) {
        this.notify(this._getTouchEvent(name, event, this));
    };
    TNSCanvasBase.prototype._readyEvent = function () {
        this.notify({
            eventName: 'ready',
            object: this,
        });
    };
    TNSCanvasBase.prototype.getAttribute = function (attrib) {
        if (attrib === 'width') {
            return this.width;
        }
        if (attrib === 'height') {
            return this.height;
        }
        return this[attrib];
    };
    TNSCanvasBase.prototype.getSize = function (value, measuredSize, type) {
        if (typeof value === 'string') {
            value = view_1.PercentLength.parse(value);
        }
        if (typeof value === 'number') {
            return value || 0;
        }
        else if ((value !== null || value !== undefined) &&
            typeof value === 'object' &&
            typeof value.value &&
            typeof value.unit) {
            if (value.unit === 'px') {
                return value.value || 0;
            }
            else if (value.unit === 'dip') {
                return view_1.layout.toDevicePixels(value.value) || 0;
            }
            else if (value.unit === '%') {
                if (application_1.orientation() === 'portrait') {
                    return type === 'width'
                        ? platform_1.screen.mainScreen.widthPixels
                        : platform_1.screen.mainScreen.heightPixels * value.value || 0;
                }
                else if (application_1.orientation() === 'landscape') {
                    return type === 'width'
                        ? platform_1.screen.mainScreen.widthPixels
                        : platform_1.screen.mainScreen.heightPixels * value.value || 0;
                }
                else {
                    return 0;
                }
            }
            else {
                return 0;
            }
        }
        else {
            return 0;
        }
    };
    TNSCanvasBase.readyEvent = 'ready';
    TNSCanvasBase = __decorate([
        view_1.CSSType('TNSCanvas'),
        __metadata("design:paramtypes", [])
    ], TNSCanvasBase);
    return TNSCanvasBase;
}(view_1.View));
exports.TNSCanvasBase = TNSCanvasBase;
var TouchList = (function (_super) {
    __extends(TouchList, _super);
    function TouchList() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TouchList.prototype.item = function (index) {
        return this[index];
    };
    return TouchList;
}(Array));
var TNSTextEncoderBase = (function () {
    function TNSTextEncoderBase(nativeInstance) {
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(TNSTextEncoderBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    TNSTextEncoderBase.prototype.encode = function (text) {
        return null;
    };
    return TNSTextEncoderBase;
}());
exports.TNSTextEncoderBase = TNSTextEncoderBase;
var TNSTextDecoderBase = (function () {
    function TNSTextDecoderBase(nativeInstance) {
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(TNSTextDecoderBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    TNSTextDecoderBase.prototype.decode = function (buffer, options) {
        return null;
    };
    return TNSTextDecoderBase;
}());
exports.TNSTextDecoderBase = TNSTextDecoderBase;
var TNSImageAssetBase = (function () {
    function TNSImageAssetBase(nativeInstance) {
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(TNSImageAssetBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    return TNSImageAssetBase;
}());
exports.TNSImageAssetBase = TNSImageAssetBase;
var TNSImageAssetSaveFormat;
(function (TNSImageAssetSaveFormat) {
    TNSImageAssetSaveFormat[TNSImageAssetSaveFormat["JPG"] = 0] = "JPG";
    TNSImageAssetSaveFormat[TNSImageAssetSaveFormat["PNG"] = 1] = "PNG";
    TNSImageAssetSaveFormat[TNSImageAssetSaveFormat["ICO"] = 2] = "ICO";
    TNSImageAssetSaveFormat[TNSImageAssetSaveFormat["BMP"] = 3] = "BMP";
    TNSImageAssetSaveFormat[TNSImageAssetSaveFormat["TIFF"] = 4] = "TIFF";
})(TNSImageAssetSaveFormat = exports.TNSImageAssetSaveFormat || (exports.TNSImageAssetSaveFormat = {}));
var TNSCanvasRenderingContext2DBase = (function () {
    function TNSCanvasRenderingContext2DBase() {
        this._type = 'none';
    }
    Object.defineProperty(TNSCanvasRenderingContext2DBase.prototype, "canvas", {
        get: function () {
            return this._canvas;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSCanvasRenderingContext2DBase.prototype, "type", {
        get: function () {
            return this._type;
        },
        enumerable: true,
        configurable: true
    });
    return TNSCanvasRenderingContext2DBase;
}());
exports.TNSCanvasRenderingContext2DBase = TNSCanvasRenderingContext2DBase;
var WebGLProgram = (function () {
    function WebGLProgram(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLProgram';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLProgram.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLProgram.prototype.toString = function () {
        return '[object WebGLProgram]';
    };
    return WebGLProgram;
}());
exports.WebGLProgram = WebGLProgram;
var WebGLShader = (function () {
    function WebGLShader(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLShader';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLShader.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLShader.prototype.toString = function () {
        return '[object WebGLShader]';
    };
    return WebGLShader;
}());
exports.WebGLShader = WebGLShader;
var WebGLBuffer = (function () {
    function WebGLBuffer(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLBuffer';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLBuffer.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLBuffer.prototype.toString = function () {
        return '[object WebGLBuffer]';
    };
    return WebGLBuffer;
}());
exports.WebGLBuffer = WebGLBuffer;
var WebGLFramebuffer = (function () {
    function WebGLFramebuffer(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLFramebuffer';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLFramebuffer.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLFramebuffer.prototype.toString = function () {
        return '[object WebGLFramebuffer]';
    };
    return WebGLFramebuffer;
}());
exports.WebGLFramebuffer = WebGLFramebuffer;
var WebGLRenderbuffer = (function () {
    function WebGLRenderbuffer(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLRenderbuffer';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLRenderbuffer.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLRenderbuffer.prototype.toString = function () {
        return '[object WebGLRenderbuffer]';
    };
    return WebGLRenderbuffer;
}());
exports.WebGLRenderbuffer = WebGLRenderbuffer;
var WebGLTexture = (function () {
    function WebGLTexture(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLTexture';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLTexture.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLTexture.prototype.toString = function () {
        return '[object WebGLTexture]';
    };
    return WebGLTexture;
}());
exports.WebGLTexture = WebGLTexture;
var WebGLActiveInfo = (function () {
    function WebGLActiveInfo(name, size, type) {
        this[Symbol.toStringTag] = 'WebGLActiveInfo';
        this.name = name;
        this.size = size;
        this.type = type;
    }
    WebGLActiveInfo.prototype.toString = function () {
        return '[object WebGLActiveInfo]';
    };
    return WebGLActiveInfo;
}());
exports.WebGLActiveInfo = WebGLActiveInfo;
var WebGLShaderPrecisionFormat = (function () {
    function WebGLShaderPrecisionFormat(rangeMin, rangeMax, precision) {
        this[Symbol.toStringTag] = 'WebGLShaderPrecisionFormat';
        this.rangeMin = rangeMin;
        this.rangeMax = rangeMax;
        this.precision = precision;
    }
    WebGLShaderPrecisionFormat.prototype.toString = function () {
        return '[object WebGLShaderPrecisionFormat]';
    };
    return WebGLShaderPrecisionFormat;
}());
exports.WebGLShaderPrecisionFormat = WebGLShaderPrecisionFormat;
var WebGLUniformLocation = (function () {
    function WebGLUniformLocation(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLUniformLocation';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLUniformLocation.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLUniformLocation.prototype.toString = function () {
        return '[object WebGLUniformLocation]';
    };
    return WebGLUniformLocation;
}());
exports.WebGLUniformLocation = WebGLUniformLocation;
var TNSWebGLRenderingContextBase = (function () {
    function TNSWebGLRenderingContextBase(context) {
        this._type = 'none';
        this._native = context;
    }
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "native", {
        get: function () {
            return this._native;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "canvas", {
        get: function () {
            return this._canvas;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "type", {
        get: function () {
            return this._type;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_BUFFER_BIT", {
        get: function () {
            return 0x00000100;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BUFFER_BIT", {
        get: function () {
            return 0x00000400;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "COLOR_BUFFER_BIT", {
        get: function () {
            return 0x00004000;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "POINTS", {
        get: function () {
            return 0x0000;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINES", {
        get: function () {
            return 0x0001;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINE_LOOP", {
        get: function () {
            return 0x0002;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINE_STRIP", {
        get: function () {
            return 0x0003;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TRIANGLES", {
        get: function () {
            return 0x0004;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TRIANGLE_STRIP", {
        get: function () {
            return 0x0005;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TRIANGLE_FAN", {
        get: function () {
            return 0x0006;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ZERO", {
        get: function () {
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ONE", {
        get: function () {
            return 1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SRC_COLOR", {
        get: function () {
            return 0x0300;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ONE_MINUS_SRC_COLOR", {
        get: function () {
            return 0x0301;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SRC_ALPHA", {
        get: function () {
            return 0x0302;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ONE_MINUS_SRC_ALPHA", {
        get: function () {
            return 0x0303;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DST_ALPHA", {
        get: function () {
            return 0x0304;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ONE_MINUS_DST_ALPHA", {
        get: function () {
            return 0x0305;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DST_COLOR", {
        get: function () {
            return 0x0306;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ONE_MINUS_DST_COLOR", {
        get: function () {
            return 0x0307;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SRC_ALPHA_SATURATE", {
        get: function () {
            return 0x0308;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CONSTANT_COLOR", {
        get: function () {
            return 0x8001;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ONE_MINUS_CONSTANT_COLOR", {
        get: function () {
            return 0x8002;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CONSTANT_ALPHA", {
        get: function () {
            return 0x8003;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ONE_MINUS_CONSTANT_ALPHA", {
        get: function () {
            return 0x8004;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FUNC_ADD", {
        get: function () {
            return 0x8006;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FUNC_SUBTRACT", {
        get: function () {
            return 0x800A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FUNC_REVERSE_SUBTRACT", {
        get: function () {
            return 0x800B;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_EQUATION", {
        get: function () {
            return 0x8009;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_EQUATION_RGB", {
        get: function () {
            return 0x8009;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_EQUATION_ALPHA", {
        get: function () {
            return 0x883D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_DST_RGB", {
        get: function () {
            return 0x80C8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_SRC_RGB", {
        get: function () {
            return 0x80C9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_DST_ALPHA", {
        get: function () {
            return 0x80CA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_SRC_ALPHA", {
        get: function () {
            return 0x80CB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND_COLOR", {
        get: function () {
            return 0x8005;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ARRAY_BUFFER_BINDING", {
        get: function () {
            return 0x8894;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ELEMENT_ARRAY_BUFFER_BINDING", {
        get: function () {
            return 0x8895;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINE_WIDTH", {
        get: function () {
            return 0x0B21;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ALIASED_POINT_SIZE_RANGE", {
        get: function () {
            return 0x846D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ALIASED_LINE_WIDTH_RANGE", {
        get: function () {
            return 0x846E;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CULL_FACE_MODE", {
        get: function () {
            return 0x0B45;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRONT_FACE", {
        get: function () {
            return 0x0B46;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_RANGE", {
        get: function () {
            return 0x0B70;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_WRITEMASK", {
        get: function () {
            return 0x0B72;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_CLEAR_VALUE", {
        get: function () {
            return 0x0B73;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_FUNC", {
        get: function () {
            return 0x0B74;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_CLEAR_VALUE", {
        get: function () {
            return 0x0B91;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_FUNC", {
        get: function () {
            return 0x0B92;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_FAIL", {
        get: function () {
            return 0x0B94;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_PASS_DEPTH_FAIL", {
        get: function () {
            return 0x0B95;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_PASS_DEPTH_PASS", {
        get: function () {
            return 0x0B96;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_REF", {
        get: function () {
            return 0x0B97;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_VALUE_MASK", {
        get: function () {
            return 0x0B93;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_WRITEMASK", {
        get: function () {
            return 0x0B98;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BACK_FUNC", {
        get: function () {
            return 0x8800;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BACK_FAIL", {
        get: function () {
            return 0x8801;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BACK_PASS_DEPTH_FAIL", {
        get: function () {
            return 0x8802;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BACK_PASS_DEPTH_PASS", {
        get: function () {
            return 0x8803;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BACK_REF", {
        get: function () {
            return 0x8CA3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BACK_VALUE_MASK", {
        get: function () {
            return 0x8CA4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BACK_WRITEMASK", {
        get: function () {
            return 0x8CA5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VIEWPORT", {
        get: function () {
            return 0x0BA2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SCISSOR_BOX", {
        get: function () {
            return 0x0C10;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "COLOR_CLEAR_VALUE", {
        get: function () {
            return 0x0C22;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "COLOR_WRITEMASK", {
        get: function () {
            return 0x0C23;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNPACK_ALIGNMENT", {
        get: function () {
            return 0x0CF5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "PACK_ALIGNMENT", {
        get: function () {
            return 0x0D05;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_TEXTURE_SIZE", {
        get: function () {
            return 0x0D33;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_VIEWPORT_DIMS", {
        get: function () {
            return 0x0D3A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SUBPIXEL_BITS", {
        get: function () {
            return 0x0D50;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RED_BITS", {
        get: function () {
            return 0x0D52;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "GREEN_BITS", {
        get: function () {
            return 0x0D53;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLUE_BITS", {
        get: function () {
            return 0x0D54;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ALPHA_BITS", {
        get: function () {
            return 0x0D55;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_BITS", {
        get: function () {
            return 0x0D56;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_BITS", {
        get: function () {
            return 0x0D57;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "POLYGON_OFFSET_UNITS", {
        get: function () {
            return 0x2A00;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "POLYGON_OFFSET_FACTOR", {
        get: function () {
            return 0x8038;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_BINDING_2D", {
        get: function () {
            return 0x8069;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLE_BUFFERS", {
        get: function () {
            return 0x80A8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLES", {
        get: function () {
            return 0x80A9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLE_COVERAGE_VALUE", {
        get: function () {
            return 0x80AA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLE_COVERAGE_INVERT", {
        get: function () {
            return 0x80AB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "COMPRESSED_TEXTURE_FORMATS", {
        get: function () {
            return 0x86A3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VENDOR", {
        get: function () {
            return 0x1F00;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERER", {
        get: function () {
            return 0x1F01;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERSION", {
        get: function () {
            return 0x1F02;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "IMPLEMENTATION_COLOR_READ_TYPE", {
        get: function () {
            return 0x8B9A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "IMPLEMENTATION_COLOR_READ_FORMAT", {
        get: function () {
            return 0x8B9B;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BROWSER_DEFAULT_WEBGL", {
        get: function () {
            return 0x9244;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STATIC_DRAW", {
        get: function () {
            return 0x88E4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STREAM_DRAW", {
        get: function () {
            return 0x88E0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DYNAMIC_DRAW", {
        get: function () {
            return 0x88E8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ARRAY_BUFFER", {
        get: function () {
            return 0x8892;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ELEMENT_ARRAY_BUFFER", {
        get: function () {
            return 0x8893;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BUFFER_SIZE", {
        get: function () {
            return 0x8764;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BUFFER_USAGE", {
        get: function () {
            return 0x8765;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CURRENT_VERTEX_ATTRIB", {
        get: function () {
            return 0x8626;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_ATTRIB_ARRAY_ENABLED", {
        get: function () {
            return 0x8622;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_ATTRIB_ARRAY_SIZE", {
        get: function () {
            return 0x8623;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_ATTRIB_ARRAY_STRIDE", {
        get: function () {
            return 0x8624;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_ATTRIB_ARRAY_TYPE", {
        get: function () {
            return 0x8625;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_ATTRIB_ARRAY_NORMALIZED", {
        get: function () {
            return 0x886A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_ATTRIB_ARRAY_POINTER", {
        get: function () {
            return 0x8645;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_ATTRIB_ARRAY_BUFFER_BINDING", {
        get: function () {
            return 0x889F;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CULL_FACE", {
        get: function () {
            return 0x0B44;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRONT", {
        get: function () {
            return 0x0404;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BACK", {
        get: function () {
            return 0x0405;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRONT_AND_BACK", {
        get: function () {
            return 0x0408;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BLEND", {
        get: function () {
            return 0x0BE2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_TEST", {
        get: function () {
            return 0x0B71;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DITHER", {
        get: function () {
            return 0x0BD0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "POLYGON_OFFSET_FILL", {
        get: function () {
            return 0x8037;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLE_ALPHA_TO_COVERAGE", {
        get: function () {
            return 0x809E;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLE_COVERAGE", {
        get: function () {
            return 0x80A0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SCISSOR_TEST", {
        get: function () {
            return 0x0C11;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_TEST", {
        get: function () {
            return 0x0B90;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NO_ERROR", {
        get: function () {
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INVALID_ENUM", {
        get: function () {
            return 0x0500;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INVALID_VALUE", {
        get: function () {
            return 0x0501;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INVALID_OPERATION", {
        get: function () {
            return 0x0502;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "OUT_OF_MEMORY", {
        get: function () {
            return 0x0505;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CONTEXT_LOST_WEBGL", {
        get: function () {
            return 0x9242;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CW", {
        get: function () {
            return 0x0900;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CCW", {
        get: function () {
            return 0x0901;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DONT_CARE", {
        get: function () {
            return 0x1100;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FASTEST", {
        get: function () {
            return 0x1101;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NICEST", {
        get: function () {
            return 0x1102;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "GENERATE_MIPMAP_HINT", {
        get: function () {
            return 0x8192;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BYTE", {
        get: function () {
            return 0x1400;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNSIGNED_BYTE", {
        get: function () {
            return 0x1401;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SHORT", {
        get: function () {
            return 0x1402;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNSIGNED_SHORT", {
        get: function () {
            return 0x1403;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INT", {
        get: function () {
            return 0x1404;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNSIGNED_INT", {
        get: function () {
            return 0x1405;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FLOAT", {
        get: function () {
            return 0x1406;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_COMPONENT", {
        get: function () {
            return 0x1902;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ALPHA", {
        get: function () {
            return 0x1906;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RGB", {
        get: function () {
            return 0x1907;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RGBA", {
        get: function () {
            return 0x1908;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LUMINANCE", {
        get: function () {
            return 0x1909;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LUMINANCE_ALPHA", {
        get: function () {
            return 0x190A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNSIGNED_SHORT_4_4_4_4", {
        get: function () {
            return 0x8033;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNSIGNED_SHORT_5_5_5_1", {
        get: function () {
            return 0x8034;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNSIGNED_SHORT_5_6_5", {
        get: function () {
            return 0x8363;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAGMENT_SHADER", {
        get: function () {
            return 0x8B30;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VERTEX_SHADER", {
        get: function () {
            return 0x8B31;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "COMPILE_STATUS", {
        get: function () {
            return 0x8B81;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DELETE_STATUS", {
        get: function () {
            return 0x8B80;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINK_STATUS", {
        get: function () {
            return 0x8B82;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "VALIDATE_STATUS", {
        get: function () {
            return 0x8B83;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ATTACHED_SHADERS", {
        get: function () {
            return 0x8B85;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ACTIVE_ATTRIBUTES", {
        get: function () {
            return 0x8B89;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ACTIVE_UNIFORMS", {
        get: function () {
            return 0x8B86;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_VERTEX_ATTRIBS", {
        get: function () {
            return 0x8869;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_VERTEX_UNIFORM_VECTORS", {
        get: function () {
            return 0x8DFB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_VARYING_VECTORS", {
        get: function () {
            return 0x8DFC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_COMBINED_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return 0x8B4D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_VERTEX_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return 0x8B4C;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return 0x8872;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_FRAGMENT_UNIFORM_VECTORS", {
        get: function () {
            return 0x8DFD;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SHADER_TYPE", {
        get: function () {
            return 0x8B4F;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SHADING_LANGUAGE_VERSION", {
        get: function () {
            return 0x8B8C;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CURRENT_PROGRAM", {
        get: function () {
            return 0x8B8D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NEVER", {
        get: function () {
            return 0x0200;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LESS", {
        get: function () {
            return 0x0201;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "EQUAL", {
        get: function () {
            return 0x0202;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LEQUAL", {
        get: function () {
            return 0x0203;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "GREATER", {
        get: function () {
            return 0x0204;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NOTEQUAL", {
        get: function () {
            return 0x0205;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "GEQUAL", {
        get: function () {
            return 0x0206;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ALWAYS", {
        get: function () {
            return 0x0207;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "KEEP", {
        get: function () {
            return 0x1E00;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "REPLACE", {
        get: function () {
            return 0x1E01;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INCR", {
        get: function () {
            return 0x1E02;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DECR", {
        get: function () {
            return 0x1E03;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INVERT", {
        get: function () {
            return 0x150A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INCR_WRAP", {
        get: function () {
            return 0x8507;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DECR_WRAP", {
        get: function () {
            return 0x8508;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NEAREST", {
        get: function () {
            return 0x2600;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINEAR", {
        get: function () {
            return 0x2601;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NEAREST_MIPMAP_NEAREST", {
        get: function () {
            return 0x2700;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINEAR_MIPMAP_NEAREST", {
        get: function () {
            return 0x2701;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NEAREST_MIPMAP_LINEAR", {
        get: function () {
            return 0x2702;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LINEAR_MIPMAP_LINEAR", {
        get: function () {
            return 0x2703;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_MAG_FILTER", {
        get: function () {
            return 0x2800;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_MIN_FILTER", {
        get: function () {
            return 0x2801;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_WRAP_S", {
        get: function () {
            return 0x2802;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_WRAP_T", {
        get: function () {
            return 0x2803;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_2D", {
        get: function () {
            return 0x0DE1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE", {
        get: function () {
            return 0x1702;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_CUBE_MAP", {
        get: function () {
            return 0x8513;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_BINDING_CUBE_MAP", {
        get: function () {
            return 0x8514;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_CUBE_MAP_POSITIVE_X", {
        get: function () {
            return 0x8515;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_X", {
        get: function () {
            return 0x8516;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_CUBE_MAP_POSITIVE_Y", {
        get: function () {
            return 0x8517;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_Y", {
        get: function () {
            return 0x8518;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_CUBE_MAP_POSITIVE_Z", {
        get: function () {
            return 0x8519;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_Z", {
        get: function () {
            return 0x851A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_CUBE_MAP_TEXTURE_SIZE", {
        get: function () {
            return 0x851C;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE0", {
        get: function () {
            return 0x84C0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE1", {
        get: function () {
            return 0x84C1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE2", {
        get: function () {
            return 0x84C2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE3", {
        get: function () {
            return 0x84C3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE4", {
        get: function () {
            return 0x84C4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE5", {
        get: function () {
            return 0x84C5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE6", {
        get: function () {
            return 0x84C6;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE7", {
        get: function () {
            return 0x84C7;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE8", {
        get: function () {
            return 0x84C8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE9", {
        get: function () {
            return 0x84C9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE10", {
        get: function () {
            return 0x84CA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE11", {
        get: function () {
            return 0x84CB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE12", {
        get: function () {
            return 0x84CC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE13", {
        get: function () {
            return 0x84CD;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE14", {
        get: function () {
            return 0x84CE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE15", {
        get: function () {
            return 0x84CF;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE16", {
        get: function () {
            return 0x84D0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE17", {
        get: function () {
            return 0x84D1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE18", {
        get: function () {
            return 0x84D2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE19", {
        get: function () {
            return 0x84D3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE20", {
        get: function () {
            return 0x84D4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE21", {
        get: function () {
            return 0x84D5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE22", {
        get: function () {
            return 0x84D6;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE23", {
        get: function () {
            return 0x84D7;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE24", {
        get: function () {
            return 0x84D8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE25", {
        get: function () {
            return 0x84D9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE26", {
        get: function () {
            return 0x84DA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE27", {
        get: function () {
            return 0x84DB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE28", {
        get: function () {
            return 0x84DC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE29", {
        get: function () {
            return 0x84DD;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE30", {
        get: function () {
            return 0x84DE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "TEXTURE31", {
        get: function () {
            return 0x84DF;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "ACTIVE_TEXTURE", {
        get: function () {
            return 0x84E0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "REPEAT", {
        get: function () {
            return 0x2901;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "CLAMP_TO_EDGE", {
        get: function () {
            return 0x812F;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MIRRORED_REPEAT", {
        get: function () {
            return 0x8370;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FLOAT_VEC2", {
        get: function () {
            return 0x8B50;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FLOAT_VEC3", {
        get: function () {
            return 0x8B51;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FLOAT_VEC4", {
        get: function () {
            return 0x8B52;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INT_VEC2", {
        get: function () {
            return 0x8B53;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INT_VEC3", {
        get: function () {
            return 0x8B54;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INT_VEC4", {
        get: function () {
            return 0x8B55;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BOOL", {
        get: function () {
            return 0x8B56;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BOOL_VEC2", {
        get: function () {
            return 0x8B57;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BOOL_VEC3", {
        get: function () {
            return 0x8B58;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "BOOL_VEC4", {
        get: function () {
            return 0x8B59;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FLOAT_MAT2", {
        get: function () {
            return 0x8B5A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FLOAT_MAT3", {
        get: function () {
            return 0x8B5B;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FLOAT_MAT4", {
        get: function () {
            return 0x8B5C;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLER_2D", {
        get: function () {
            return 0x8B5E;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "SAMPLER_CUBE", {
        get: function () {
            return 0x8B60;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LOW_FLOAT", {
        get: function () {
            return 0x8DF0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MEDIUM_FLOAT", {
        get: function () {
            return 0x8DF1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "HIGH_FLOAT", {
        get: function () {
            return 0x8DF2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "LOW_INT", {
        get: function () {
            return 0x8DF3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MEDIUM_INT", {
        get: function () {
            return 0x8DF4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "HIGH_INT", {
        get: function () {
            return 0x8DF5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER", {
        get: function () {
            return 0x8D40;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER", {
        get: function () {
            return 0x8D41;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RGBA4", {
        get: function () {
            return 0x8056;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RGB5_A1", {
        get: function () {
            return 0x8057;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RGB565", {
        get: function () {
            return 0x8D62;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_COMPONENT16", {
        get: function () {
            return 0x81A5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_INDEX8", {
        get: function () {
            return 0x8D48;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_STENCIL", {
        get: function () {
            return 0x84F9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_WIDTH", {
        get: function () {
            return 0x8D42;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_HEIGHT", {
        get: function () {
            return 0x8D43;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_INTERNAL_FORMAT", {
        get: function () {
            return 0x8D44;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_RED_SIZE", {
        get: function () {
            return 0x8D50;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_GREEN_SIZE", {
        get: function () {
            return 0x8D51;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_BLUE_SIZE", {
        get: function () {
            return 0x8D52;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_ALPHA_SIZE", {
        get: function () {
            return 0x8D53;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_DEPTH_SIZE", {
        get: function () {
            return 0x8D54;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_STENCIL_SIZE", {
        get: function () {
            return 0x8D55;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE", {
        get: function () {
            return 0x8CD0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_ATTACHMENT_OBJECT_NAME", {
        get: function () {
            return 0x8CD1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL", {
        get: function () {
            return 0x8CD2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE", {
        get: function () {
            return 0x8CD3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "COLOR_ATTACHMENT0", {
        get: function () {
            return 0x8CE0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_ATTACHMENT", {
        get: function () {
            return 0x8D00;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "STENCIL_ATTACHMENT", {
        get: function () {
            return 0x8D20;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "DEPTH_STENCIL_ATTACHMENT", {
        get: function () {
            return 0x821A;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "NONE", {
        get: function () {
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_COMPLETE", {
        get: function () {
            return 0x8CD5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_INCOMPLETE_ATTACHMENT", {
        get: function () {
            return 0x8CD6;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT", {
        get: function () {
            return 0x8CD7;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_INCOMPLETE_DIMENSIONS", {
        get: function () {
            return 0x8CD9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_UNSUPPORTED", {
        get: function () {
            return 0x8CDD;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "FRAMEBUFFER_BINDING", {
        get: function () {
            return 0x8CA6;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "RENDERBUFFER_BINDING", {
        get: function () {
            return 0x8CA7;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "MAX_RENDERBUFFER_SIZE", {
        get: function () {
            return 0x84E8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "INVALID_FRAMEBUFFER_OPERATION", {
        get: function () {
            return 0x0506;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNPACK_FLIP_Y_WEBGL", {
        get: function () {
            return 0x9240;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNPACK_PREMULTIPLY_ALPHA_WEBGL", {
        get: function () {
            return 0x9241;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContextBase.prototype, "UNPACK_COLORSPACE_CONVERSION_WEBGL", {
        get: function () {
            return 0x9243;
        },
        enumerable: true,
        configurable: true
    });
    TNSWebGLRenderingContextBase.prototype.toNativeArray = function (value, type) {
        return [];
    };
    return TNSWebGLRenderingContextBase;
}());
exports.TNSWebGLRenderingContextBase = TNSWebGLRenderingContextBase;
var TNSPath2DBase = (function () {
    function TNSPath2DBase(instance) {
        this.nativeInstance = instance;
    }
    Object.defineProperty(TNSPath2DBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    return TNSPath2DBase;
}());
exports.TNSPath2DBase = TNSPath2DBase;
var TNSDOMMatrixBase = (function () {
    function TNSDOMMatrixBase(nativeInstance) {
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(TNSDOMMatrixBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    return TNSDOMMatrixBase;
}());
exports.TNSDOMMatrixBase = TNSDOMMatrixBase;
var ImageDataBase = (function () {
    function ImageDataBase(nativeInstance) {
        this.width = 0;
        this.height = 0;
        this.data = null;
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(ImageDataBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    return ImageDataBase;
}());
exports.ImageDataBase = ImageDataBase;
var CanvasGradientBase = (function () {
    function CanvasGradientBase() {
    }
    return CanvasGradientBase;
}());
exports.CanvasGradientBase = CanvasGradientBase;
var CanvasPatternBase = (function () {
    function CanvasPatternBase(nativeInstance) {
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(CanvasPatternBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    return CanvasPatternBase;
}());
exports.CanvasPatternBase = CanvasPatternBase;
var TextMetricsBase = (function () {
    function TextMetricsBase(nativeInstance) {
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(TextMetricsBase.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    return TextMetricsBase;
}());
exports.TextMetricsBase = TextMetricsBase;
var WebGLQuery = (function () {
    function WebGLQuery(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLQuery';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLQuery.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLQuery.prototype.toString = function () {
        return '[object WebGLQuery]';
    };
    return WebGLQuery;
}());
exports.WebGLQuery = WebGLQuery;
var WebGLSampler = (function () {
    function WebGLSampler(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLSampler';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLSampler.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLSampler.prototype.toString = function () {
        return '[object WebGLSampler]';
    };
    return WebGLSampler;
}());
exports.WebGLSampler = WebGLSampler;
var WebGLTransformFeedback = (function () {
    function WebGLTransformFeedback(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLTransformFeedback';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLTransformFeedback.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLTransformFeedback.prototype.toString = function () {
        return '[object WebGLTransformFeedback]';
    };
    return WebGLTransformFeedback;
}());
exports.WebGLTransformFeedback = WebGLTransformFeedback;
var WebGLVertexArrayObject = (function () {
    function WebGLVertexArrayObject(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLVertexArrayObject';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLVertexArrayObject.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLVertexArrayObject.prototype.toString = function () {
        return '[object WebGLVertexArrayObject]';
    };
    return WebGLVertexArrayObject;
}());
exports.WebGLVertexArrayObject = WebGLVertexArrayObject;
var WebGLSync = (function () {
    function WebGLSync(nativeInstance) {
        this[Symbol.toStringTag] = 'WebGLSync';
        this.nativeInstance = nativeInstance;
    }
    Object.defineProperty(WebGLSync.prototype, "native", {
        get: function () {
            return this.nativeInstance;
        },
        enumerable: true,
        configurable: true
    });
    WebGLSync.prototype.toString = function () {
        return '[object WebGLSync]';
    };
    return WebGLSync;
}());
exports.WebGLSync = WebGLSync;
//# sourceMappingURL=canvas-plugin.common.js.map