"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var view_1 = require("@nativescript/core/ui/core/view");
var SVG_1 = require("./SVG");
var SVGItem = (function (_super) {
    __extends(SVGItem, _super);
    function SVGItem() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(SVGItem.prototype, "stroke", {
        get: function () {
            return this.style.stroke;
        },
        set: function (value) {
            this.style.stroke = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SVGItem.prototype, "strokeWidth", {
        get: function () {
            return this.style.strokeWidth;
        },
        set: function (value) {
            this.style.strokeWidth = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SVGItem.prototype, "fill", {
        get: function () {
            return this.style.fill;
        },
        set: function (value) {
            this.style.fill = value;
        },
        enumerable: true,
        configurable: true
    });
    SVGItem.prototype._parseOpacity = function (value) {
        if (typeof value === 'string') {
            if (value.indexOf('%') > -1) {
                var percent = parseInt(value.replace('%', ''), 10);
                value = isNaN(percent) ? 1 : percent / 100;
            }
            else {
                var percent = parseFloat(value);
                value = isNaN(percent) ? 1 : percent;
            }
        }
        return value;
    };
    Object.defineProperty(SVGItem.prototype, "fillOpacity", {
        get: function () {
            return this.style.fillOpacity;
        },
        set: function (value) {
            value = this._parseOpacity(value);
            this.style.fillOpacity = value;
        },
        enumerable: true,
        configurable: true
    });
    SVGItem.prototype._doStroke = function () {
        return this._realStroke !== undefined && this._realStroke !== 'none';
    };
    SVGItem.prototype._doFill = function () {
        return this._realFill !== 'none';
    };
    SVGItem.prototype._doFillOpacity = function () {
        return this._realFillOpacity !== undefined;
    };
    Object.defineProperty(SVGItem.prototype, "_realFillOpacity", {
        get: function () {
            if ((this.parent && this.parent.fillOpacity) !== undefined && this.fillOpacity !== undefined) {
                return this._parseOpacity(this.fillOpacity);
            }
            return this._parseOpacity((this.parent && this.parent.fillOpacity)) || this._parseOpacity(this.fillOpacity);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SVGItem.prototype, "_realStroke", {
        get: function () {
            if ((this.parent && this.parent.stroke) !== undefined && this.stroke !== undefined) {
                return this.stroke;
            }
            return (this.parent && this.parent.stroke) || this.stroke;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SVGItem.prototype, "_realFill", {
        get: function () {
            if ((this.parent && this.parent.fill) !== undefined && this.fill !== undefined) {
                return this.fill;
            }
            return (this.parent && this.parent.fill) || this.fill;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SVGItem.prototype, "_realOpacity", {
        get: function () {
            if ((this.parent && this.parent.opacity) !== undefined && this.opacity !== undefined) {
                return this.opacity;
            }
            return (this.parent && this.parent.opacity) || this.opacity || 1;
        },
        enumerable: true,
        configurable: true
    });
    SVGItem.prototype._getRealSize = function (value, parent, type) {
        if (!parent) {
            parent = this.parent;
            while (!(parent instanceof SVG_1.SVG)) {
                parent = parent.parent;
                if (parent === undefined || parent === null) {
                    break;
                }
            }
            if (parent instanceof SVG_1.SVG && (type === 'width' || type === 'height')) {
                if (type === 'width') {
                    parent = parent.getMeasuredWidth();
                }
                if (type === 'height') {
                    parent = parent.getMeasuredHeight();
                }
            }
        }
        var base = parent || 0;
        var size;
        if (value && value.unit === '%') {
            size = view_1.PercentLength.convertToString(value);
        }
        if (typeof value === 'string' || typeof value === 'number') {
            size = value;
        }
        if (typeof size === 'string' && (size.indexOf('%') > -1)) {
            size = (base * (parseInt(size.replace('%', '')) / 100));
        }
        return size;
    };
    SVGItem.prototype._appendChild = function (id, child) {
        var parent = this.parent;
        while (!(parent instanceof SVG_1.SVG)) {
            parent = parent.parent;
            if (parent === undefined || parent === null) {
                break;
            }
        }
        if (parent instanceof SVG_1.SVG) {
            parent._children.set(id, child);
        }
    };
    SVGItem.prototype._removeChild = function (id) {
        var parent = this.parent;
        while (!(parent instanceof SVG_1.SVG)) {
            parent = parent.parent;
            if (parent === undefined || parent === null) {
                break;
            }
        }
        if (parent instanceof SVG_1.SVG) {
            parent._children.delete(id);
        }
    };
    SVGItem.prototype._getViewById = function (name) {
        var parent = this.parent;
        while (!(parent instanceof SVG_1.SVG)) {
            parent = parent.parent;
            if (parent === undefined || parent == null) {
                break;
            }
        }
        if (!parent) {
            return null;
        }
        return parent._getViewById(name);
    };
    return SVGItem;
}(view_1.View));
exports.SVGItem = SVGItem;
//# sourceMappingURL=SVGItem.js.map